@@ -31,12 +31,12 @@
     <message>
         <location filename="../builtincommandlineoption.cpp" line="51"/>
         <source>Display Jump to Track dialog</source>
-        <translation>顯示跳轉至軌道對話框</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../builtincommandlineoption.cpp" line="52"/>
         <source>Quit application</source>
-        <translation>退出應用程式</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../builtincommandlineoption.cpp" line="53"/>
@@ -46,17 +46,17 @@
     <message>
         <location filename="../builtincommandlineoption.cpp" line="54"/>
         <source>Print volume level</source>
-        <translation>列印音量等級</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../builtincommandlineoption.cpp" line="55"/>
         <source>Mute/Restore volume</source>
-        <translation>靜音/恢復音量</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../builtincommandlineoption.cpp" line="56"/>
         <source>Print mute status</source>
-        <translation>列印靜音狀態</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../builtincommandlineoption.cpp" line="57"/>
@@ -76,7 +76,7 @@
     <message>
         <location filename="../builtincommandlineoption.cpp" line="60"/>
         <source>Show main window</source>
-        <translation>顯示主視窗</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../builtincommandlineoption.cpp" line="61"/>
@@ -97,88 +97,88 @@
         <translation>未知指令</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="479"/>
+        <location filename="../qmmpstarter.cpp" line="508"/>
         <source>Usage: qmmp [options] [files]</source>
         <translation>使用：qmmp [設定] [文件]</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="480"/>
+        <location filename="../qmmpstarter.cpp" line="509"/>
         <source>Options:</source>
         <translation>設定：</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="486"/>
+        <location filename="../qmmpstarter.cpp" line="515"/>
         <source>Start qmmp with the specified user interface</source>
-        <translation>使用指定的使用者介面啟動 qmmp</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="487"/>
+        <location filename="../qmmpstarter.cpp" line="516"/>
         <source>List all available user interfaces</source>
-        <translation>列出所有可用的使用者介面</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="488"/>
+        <location filename="../qmmpstarter.cpp" line="517"/>
         <source>Don&apos;t start the application</source>
         <translation>無法啟動此程式</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="489"/>
+        <location filename="../qmmpstarter.cpp" line="518"/>
         <source>Print debugging messages</source>
-        <translation>列印偵錯訊息</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="490"/>
+        <location filename="../qmmpstarter.cpp" line="519"/>
         <source>Display this text and exit</source>
         <translation>察看這些字檔並結束</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="491"/>
+        <location filename="../qmmpstarter.cpp" line="520"/>
         <source>Print version number and exit</source>
         <translation>察看版本並結束</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="493"/>
+        <location filename="../qmmpstarter.cpp" line="522"/>
         <source>Home page: %1</source>
-        <translation>首頁：%1</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="494"/>
+        <location filename="../qmmpstarter.cpp" line="523"/>
         <source>Development page: %1</source>
-        <translation>開發頁面：%1</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="495"/>
+        <location filename="../qmmpstarter.cpp" line="524"/>
         <source>Bug tracker: %1</source>
-        <translation>錯誤追蹤器：%1</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../qmmpstarter.cpp" line="171"/>
-        <location filename="../qmmpstarter.cpp" line="500"/>
+        <location filename="../qmmpstarter.cpp" line="529"/>
         <source>Command Line Help</source>
-        <translation>命令列幫助</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="513"/>
+        <location filename="../qmmpstarter.cpp" line="542"/>
         <source>QMMP version: %1</source>
-        <translation>QMP 版本：%1</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="514"/>
+        <location filename="../qmmpstarter.cpp" line="543"/>
         <source>Compiled with Qt version: %1</source>
-        <translation>使用 Qt 版本編譯：%1</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="515"/>
+        <location filename="../qmmpstarter.cpp" line="544"/>
         <source>Using Qt version: %1</source>
-        <translation>使用 Qt 版本：%1</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="518"/>
+        <location filename="../qmmpstarter.cpp" line="547"/>
         <source>Qmmp Version</source>
-        <translation>Qmmp版本</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="535"/>
+        <location filename="../qmmpstarter.cpp" line="564"/>
         <source>User Interfaces</source>
         <translation>使用者介面</translation>
     </message>
