@@ -6,17 +6,17 @@
     <message>
         <location filename="../seekoption.cpp" line="29"/>
         <source>Seek to position in the current track</source>
-        <translation>Verplaats naar positie in huidige nummer</translation>
+        <translation>Doorspoelen naar positie in huidig nummer</translation>
     </message>
     <message>
         <location filename="../seekoption.cpp" line="30"/>
         <source>Seek forward</source>
-        <translation>Verplaats naar voren</translation>
+        <translation>Vooruitspoelen</translation>
     </message>
     <message>
         <location filename="../seekoption.cpp" line="31"/>
         <source>Seek backwards</source>
-        <translation>Verplaats naar achteren</translation>
+        <translation>Terugspoelen</translation>
     </message>
 </context>
 </TS>
