@@ -1,6 +1,50 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="it">
+<context>
+    <name>Bs2bSettingsDialog</name>
+    <message>
+        <location filename="../bs2bsettingsdialog.ui" line="14"/>
+        <source>BS2B Plugin Settings</source>
+        <translation>Impostazioni dell&apos;estensione BS2B</translation>
+    </message>
+    <message>
+        <location filename="../bs2bsettingsdialog.ui" line="32"/>
+        <source>Crossfeed level</source>
+        <translation>Livello di crossfeed</translation>
+    </message>
+    <message>
+        <location filename="../bs2bsettingsdialog.ui" line="45"/>
+        <location filename="../bs2bsettingsdialog.ui" line="59"/>
+        <source>-</source>
+        <translation>-</translation>
+    </message>
+    <message>
+        <location filename="../bs2bsettingsdialog.ui" line="71"/>
+        <source>Default</source>
+        <translation>Predefinito</translation>
+    </message>
+    <message>
+        <location filename="../bs2bsettingsdialog.ui" line="78"/>
+        <source>C.Moy</source>
+        <translation>C.Moy</translation>
+    </message>
+    <message>
+        <location filename="../bs2bsettingsdialog.ui" line="85"/>
+        <source>J. Meier</source>
+        <translation>J. Meier</translation>
+    </message>
+    <message>
+        <location filename="../bs2bsettingsdialog.cpp" line="61"/>
+        <source>%1 Hz, %2 us</source>
+        <translation>%1 Hz, %2 us</translation>
+    </message>
+    <message>
+        <location filename="../bs2bsettingsdialog.cpp" line="68"/>
+        <source>%1 dB</source>
+        <translation>%1 dB</translation>
+    </message>
+</context>
 <context>
     <name>EffectBs2bFactory</name>
     <message>
@@ -9,7 +53,7 @@
         <translation>Estensione BS2B</translation>
     </message>
     <message>
-        <location filename="../effectbs2bfactory.cpp" line="51"/>
+        <location filename="../effectbs2bfactory.cpp" line="50"/>
         <source>About BS2B Effect Plugin</source>
         <translation>Informazioni sull&apos;estensione effetti BS2B</translation>
     </message>
@@ -19,73 +63,29 @@
         <translation>Versione per Qmmp dell&apos;effetto DSP per cuffie «Bauer stereophonic-to-binaural» di Boris Mikhaylov, abbreviato in bs2b.</translation>
     </message>
     <message>
-        <location filename="../effectbs2bfactory.cpp" line="54"/>
+        <location filename="../effectbs2bfactory.cpp" line="55"/>
         <source>Visit %1 for more details</source>
         <translation>Visita %1 per maggiori informazioni</translation>
     </message>
     <message>
-        <location filename="../effectbs2bfactory.cpp" line="56"/>
+        <location filename="../effectbs2bfactory.cpp" line="57"/>
         <source>Compiled against libbs2b-%1</source>
         <translation>Compilato con libbs2b-%1</translation>
     </message>
     <message>
-        <location filename="../effectbs2bfactory.cpp" line="57"/>
+        <location filename="../effectbs2bfactory.cpp" line="59"/>
         <source>Developers:</source>
         <translation>Sviluppatori:</translation>
     </message>
     <message>
-        <location filename="../effectbs2bfactory.cpp" line="58"/>
+        <location filename="../effectbs2bfactory.cpp" line="60"/>
         <source>Ilya Kotov &amp;lt;forkotov02@ya.ru&amp;gt;</source>
         <translation>Ilya Kotov &amp;lt;forkotov02@ya.ru&amp;gt;</translation>
     </message>
     <message>
-        <location filename="../effectbs2bfactory.cpp" line="59"/>
+        <location filename="../effectbs2bfactory.cpp" line="61"/>
         <source>Sebastian Pipping &amp;lt;sebastian@pipping.org&amp;gt;</source>
         <translation>Sebastian Pipping &amp;lt;sebastian@pipping.org&amp;gt;</translation>
     </message>
 </context>
-<context>
-    <name>SettingsDialog</name>
-    <message>
-        <location filename="../settingsdialog.ui" line="14"/>
-        <source>BS2B Plugin Settings</source>
-        <translation>Impostazioni dell&apos;estensione BS2B</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="32"/>
-        <source>Crossfeed level</source>
-        <translation>Livello di crossfeed</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="45"/>
-        <location filename="../settingsdialog.ui" line="59"/>
-        <source>-</source>
-        <translation>-</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="71"/>
-        <source>Default</source>
-        <translation>Predefinito</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="78"/>
-        <source>C.Moy</source>
-        <translation>C.Moy</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="85"/>
-        <source>J. Meier</source>
-        <translation>J. Meier</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="60"/>
-        <source>%1 Hz, %2 us</source>
-        <translation>%1 Hz, %2 us</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="67"/>
-        <source>%1 dB</source>
-        <translation>%1 dB</translation>
-    </message>
-</context>
 </TS>
