@@ -17,7 +17,7 @@
         <location filename="../bs2bsettingsdialog.ui" line="45"/>
         <location filename="../bs2bsettingsdialog.ui" line="59"/>
         <source>-</source>
-        <translation>-</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../bs2bsettingsdialog.ui" line="71"/>
@@ -27,22 +27,22 @@
     <message>
         <location filename="../bs2bsettingsdialog.ui" line="78"/>
         <source>C.Moy</source>
-        <translation>C.Moy</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../bs2bsettingsdialog.ui" line="85"/>
         <source>J. Meier</source>
-        <translation>J. Meier</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../bs2bsettingsdialog.cpp" line="61"/>
         <source>%1 Hz, %2 us</source>
-        <translation>%1 Hz, %2 us</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../bs2bsettingsdialog.cpp" line="68"/>
         <source>%1 dB</source>
-        <translation>%1 dB</translation>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -50,7 +50,7 @@
     <message>
         <location filename="../effectbs2bfactory.cpp" line="31"/>
         <source>BS2B Plugin</source>
-        <translation>BS2B 插件</translation>
+        <translation>BS2B 外掛</translation>
     </message>
     <message>
         <location filename="../effectbs2bfactory.cpp" line="50"/>
@@ -80,12 +80,12 @@
     <message>
         <location filename="../effectbs2bfactory.cpp" line="60"/>
         <source>Ilya Kotov &amp;lt;forkotov02@ya.ru&amp;gt;</source>
-        <translation>Ilya Kotov &amp;lt;forkotov02@ya.ru&amp;gt;</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../effectbs2bfactory.cpp" line="61"/>
         <source>Sebastian Pipping &amp;lt;sebastian@pipping.org&amp;gt;</source>
-        <translation>Sebastian Pipping &amp;lt;sebastian@pipping.org&amp;gt;</translation>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 </TS>
