@@ -1,6 +1,24 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="zh_TW">
+<context>
+    <name>CrossfadeSettingsDialog</name>
+    <message>
+        <location filename="../crossfadesettingsdialog.ui" line="14"/>
+        <source>Crossfade Plugin Settings</source>
+        <translation>交叉衰落插件設定</translation>
+    </message>
+    <message>
+        <location filename="../crossfadesettingsdialog.ui" line="29"/>
+        <source>Overlap:</source>
+        <translation>重迭：</translation>
+    </message>
+    <message>
+        <location filename="../crossfadesettingsdialog.ui" line="42"/>
+        <source>ms</source>
+        <translation>毫秒</translation>
+    </message>
+</context>
 <context>
     <name>EffectCrossfadeFactory</name>
     <message>
@@ -9,37 +27,19 @@
         <translation>交叉衰落插件</translation>
     </message>
     <message>
-        <location filename="../effectcrossfadefactory.cpp" line="51"/>
+        <location filename="../effectcrossfadefactory.cpp" line="50"/>
         <source>About Crossfade Plugin</source>
         <translation>關於交叉衰落插件</translation>
     </message>
     <message>
-        <location filename="../effectcrossfadefactory.cpp" line="52"/>
+        <location filename="../effectcrossfadefactory.cpp" line="51"/>
         <source>Qmmp Crossfade Plugin</source>
         <translation>Qmmp 交叉衰落插件</translation>
     </message>
     <message>
-        <location filename="../effectcrossfadefactory.cpp" line="53"/>
+        <location filename="../effectcrossfadefactory.cpp" line="52"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
         <translation>撰寫：Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
 </context>
-<context>
-    <name>SettingsDialog</name>
-    <message>
-        <location filename="../settingsdialog.ui" line="14"/>
-        <source>Crossfade Plugin Settings</source>
-        <translation>交叉衰落插件設定</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="29"/>
-        <source>Overlap:</source>
-        <translation>重迭：</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="42"/>
-        <source>ms</source>
-        <translation>毫秒</translation>
-    </message>
-</context>
 </TS>
