@@ -6,20 +6,20 @@
     <message>
         <location filename="../effectmonotostereofactory.cpp" line="29"/>
         <source>Mono to Stereo Converter Plugin</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../effectmonotostereofactory.cpp" line="48"/>
-        <source>About Mono to Stereo Converter Plugin</source>
-        <translation type="unfinished"></translation>
+        <translation>Estensione di conversione da mono a stereo</translation>
     </message>
     <message>
         <location filename="../effectmonotostereofactory.cpp" line="49"/>
-        <source>Qmmp Mono to Stereo Converter Plugin</source>
-        <translation type="unfinished"></translation>
+        <source>About Mono to Stereo Converter Plugin</source>
+        <translation>Informazioni sull&apos;estensione di conversione da mono a stereo</translation>
     </message>
     <message>
         <location filename="../effectmonotostereofactory.cpp" line="50"/>
+        <source>Qmmp Mono to Stereo Converter Plugin</source>
+        <translation>Estensione di conversione da mono a stereo per Qmmp</translation>
+    </message>
+    <message>
+        <location filename="../effectmonotostereofactory.cpp" line="51"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
         <translation>Autori: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
