@@ -9,47 +9,42 @@
         <translation>立体聲擴展插件</translation>
     </message>
     <message>
-        <location filename="../effectstereofactory.cpp" line="50"/>
+        <location filename="../effectstereofactory.cpp" line="49"/>
         <source>About Extra Stereo Plugin</source>
         <translation>關於立体聲擴展插件</translation>
     </message>
     <message>
-        <location filename="../effectstereofactory.cpp" line="51"/>
+        <location filename="../effectstereofactory.cpp" line="50"/>
         <source>Qmmp Extra Stereo Plugin</source>
         <translation>Qmmp 立体聲擴展插件</translation>
     </message>
     <message>
-        <location filename="../effectstereofactory.cpp" line="52"/>
+        <location filename="../effectstereofactory.cpp" line="51"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
         <translation>撰寫：Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
     <message>
-        <location filename="../effectstereofactory.cpp" line="53"/>
+        <location filename="../effectstereofactory.cpp" line="52"/>
         <source>Based on the Extra Stereo Plugin for Xmms by Johan Levin</source>
         <translation>基於 Johan Levin 的 Xmms 立体聲擴展插件</translation>
     </message>
 </context>
 <context>
-    <name>SettingsDialog</name>
+    <name>StereoSettingsDialog</name>
     <message>
-        <location filename="../settingsdialog.ui" line="14"/>
+        <location filename="../stereosettingsdialog.ui" line="14"/>
         <source>Extra Stereo Plugin Settings</source>
         <translation>立体聲擴展插件設定</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="31"/>
+        <location filename="../stereosettingsdialog.ui" line="31"/>
         <source>Effect intensity:</source>
         <translation>效果強度</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="54"/>
+        <location filename="../stereosettingsdialog.ui" line="54"/>
         <source>-</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="57"/>
-        <source>%1</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 </TS>
