@@ -14,22 +14,22 @@
         <translation>視頻文件</translation>
     </message>
     <message>
-        <location filename="../mplayerenginefactory.cpp" line="74"/>
+        <location filename="../mplayerenginefactory.cpp" line="73"/>
         <source>About MPlayer Plugin</source>
         <translation>關於 Mplayer 外掛</translation>
     </message>
     <message>
-        <location filename="../mplayerenginefactory.cpp" line="75"/>
+        <location filename="../mplayerenginefactory.cpp" line="74"/>
         <source>Qmmp MPlayer Plugin</source>
         <translation>Qmmp Mplayer 外掛</translation>
     </message>
     <message>
-        <location filename="../mplayerenginefactory.cpp" line="76"/>
+        <location filename="../mplayerenginefactory.cpp" line="75"/>
         <source>This plugin uses MPlayer as backend</source>
         <translation>此插件使用 Mplayer 後端</translation>
     </message>
     <message>
-        <location filename="../mplayerenginefactory.cpp" line="77"/>
+        <location filename="../mplayerenginefactory.cpp" line="76"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
         <translation>撰寫：Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
@@ -37,126 +37,126 @@
 <context>
     <name>MplayerMetaDataModel</name>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="38"/>
+        <location filename="../mplayermetadatamodel.cpp" line="57"/>
         <source>Size</source>
         <translation>大小：</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="38"/>
+        <location filename="../mplayermetadatamodel.cpp" line="57"/>
         <source>KiB</source>
         <translation>KiB</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="56"/>
+        <location filename="../mplayermetadatamodel.cpp" line="58"/>
         <source>Demuxer</source>
         <translation>流分離</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="58"/>
+        <location filename="../mplayermetadatamodel.cpp" line="60"/>
         <source>Video format</source>
         <translation>視頻格式</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="59"/>
+        <location filename="../mplayermetadatamodel.cpp" line="61"/>
         <source>FPS</source>
         <translation>FPS</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="60"/>
+        <location filename="../mplayermetadatamodel.cpp" line="62"/>
         <source>Video codec</source>
         <translation>視頻編碼</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="61"/>
+        <location filename="../mplayermetadatamodel.cpp" line="63"/>
         <source>Aspect ratio</source>
         <translation>寬高比：</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="62"/>
+        <location filename="../mplayermetadatamodel.cpp" line="64"/>
         <source>Video bitrate</source>
         <translation>視頻比特率</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="62"/>
-        <location filename="../mplayermetadatamodel.cpp" line="66"/>
+        <location filename="../mplayermetadatamodel.cpp" line="64"/>
+        <location filename="../mplayermetadatamodel.cpp" line="68"/>
         <source>kbps</source>
         <translation>kbps</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="64"/>
+        <location filename="../mplayermetadatamodel.cpp" line="66"/>
         <source>Audio codec</source>
         <translation>音頻編碼</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="65"/>
+        <location filename="../mplayermetadatamodel.cpp" line="67"/>
         <source>Sample rate</source>
         <translation>取樣率</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="65"/>
+        <location filename="../mplayermetadatamodel.cpp" line="67"/>
         <source>Hz</source>
         <translation>Hz</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="66"/>
+        <location filename="../mplayermetadatamodel.cpp" line="68"/>
         <source>Audio bitrate</source>
         <translation>音頻比特率</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="67"/>
+        <location filename="../mplayermetadatamodel.cpp" line="69"/>
         <source>Channels</source>
         <translation>音頻通道</translation>
     </message>
     <message>
-        <location filename="../mplayermetadatamodel.cpp" line="63"/>
+        <location filename="../mplayermetadatamodel.cpp" line="65"/>
         <source>Resolution</source>
         <translation>分辨率</translation>
     </message>
 </context>
 <context>
-    <name>SettingsDialog</name>
+    <name>MplayerSettingsDialog</name>
     <message>
-        <location filename="../settingsdialog.ui" line="14"/>
+        <location filename="../mplayersettingsdialog.ui" line="14"/>
         <source>MPlayer Settings</source>
         <translation>Mplayer 設置</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="34"/>
+        <location filename="../mplayersettingsdialog.ui" line="34"/>
         <source>Video:</source>
         <translation>視頻：</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="48"/>
+        <location filename="../mplayersettingsdialog.ui" line="48"/>
         <source>Audio:</source>
         <translation>音頻：</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="62"/>
+        <location filename="../mplayersettingsdialog.ui" line="62"/>
         <source>Audio/video auto synchronization</source>
         <translation>音頻/視頻自動同步</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="72"/>
+        <location filename="../mplayersettingsdialog.ui" line="72"/>
         <source>Synchronization factor:</source>
         <translation>同步數系數：</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="89"/>
+        <location filename="../mplayersettingsdialog.ui" line="89"/>
         <source>Extra options:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="96"/>
+        <location filename="../mplayersettingsdialog.ui" line="96"/>
         <source>Extra command line options</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="29"/>
-        <location filename="../settingsdialog.cpp" line="37"/>
-        <location filename="../settingsdialog.cpp" line="46"/>
-        <location filename="../settingsdialog.cpp" line="47"/>
-        <location filename="../settingsdialog.cpp" line="61"/>
-        <location filename="../settingsdialog.cpp" line="62"/>
+        <location filename="../mplayersettingsdialog.cpp" line="29"/>
+        <location filename="../mplayersettingsdialog.cpp" line="33"/>
+        <location filename="../mplayersettingsdialog.cpp" line="37"/>
+        <location filename="../mplayersettingsdialog.cpp" line="38"/>
+        <location filename="../mplayersettingsdialog.cpp" line="54"/>
+        <location filename="../mplayersettingsdialog.cpp" line="55"/>
         <source>default</source>
         <translation>預設</translation>
     </message>
