@@ -1,32 +1,32 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="zh_TW">
+<TS version="2.1" language="zh_TW">
 <context>
     <name>GnomeHotkeyFactory</name>
     <message>
-        <location filename="../gnomehotkeyfactory.cpp" line="30"/>
+        <location filename="../gnomehotkeyfactory.cpp" line="29"/>
         <source>Gnome Hotkey Plugin</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gnomehotkeyfactory.cpp" line="51"/>
+        <location filename="../gnomehotkeyfactory.cpp" line="50"/>
         <source>About Gnome Hotkey Plugin</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gnomehotkeyfactory.cpp" line="52"/>
+        <location filename="../gnomehotkeyfactory.cpp" line="51"/>
         <source>Qmmp Gnome Hotkey Plugin</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gnomehotkeyfactory.cpp" line="53"/>
+        <location filename="../gnomehotkeyfactory.cpp" line="52"/>
         <source>This plugin adds support of the GNOME/Cinnamon hotkeys</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gnomehotkeyfactory.cpp" line="54"/>
+        <location filename="../gnomehotkeyfactory.cpp" line="53"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
-        <translation>作者：Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
+        <translation>撰寫：Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
 </context>
 </TS>
