@@ -19,7 +19,7 @@
     <message>
         <location filename="../history.cpp" line="58"/>
         <source>Alt+H</source>
-        <translation>Alt+H</translation>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -156,39 +156,39 @@
         <translation>Genre</translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="126"/>
+        <location filename="../historywindow.cpp" line="130"/>
         <source>dd MMMM yyyy</source>
         <translation>jj MMMM aaaa</translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="127"/>
+        <location filename="../historywindow.cpp" line="131"/>
         <source>hh:mm:ss</source>
         <translation>hh:mm:ss</translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="194"/>
+        <location filename="../historywindow.cpp" line="198"/>
         <source>MM-yyyy</source>
         <translation>MM-aaaa</translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="195"/>
+        <location filename="../historywindow.cpp" line="199"/>
         <source>dd MMMM</source>
         <translation>jj MMMM</translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="495"/>
+        <location filename="../historywindow.cpp" line="499"/>
         <source>Add to Playlist</source>
         <translation>Ajouter à la liste</translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="496"/>
+        <location filename="../historywindow.cpp" line="500"/>
         <source>&amp;View Track Details</source>
         <translation>&amp;Voir les détails du morceau</translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="498"/>
+        <location filename="../historywindow.cpp" line="502"/>
         <source>Remove from History</source>
-        <translation>Supprimer de l&apos;historique</translation>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 </TS>
