@@ -14,12 +14,12 @@
     <message>
         <location filename="../history.cpp" line="57"/>
         <source>History</source>
-        <translation>历史</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../history.cpp" line="58"/>
         <source>Alt+H</source>
-        <translation>Alt+H</translation>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -27,27 +27,27 @@
     <message>
         <location filename="../historyfactory.cpp" line="31"/>
         <source>Listening History Plugin</source>
-        <translation>收听历史插件</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../historyfactory.cpp" line="51"/>
         <source>About Listening History Plugin</source>
-        <translation>关于收听历史插件</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../historyfactory.cpp" line="52"/>
         <source>Qmmp Listening History Plugin</source>
-        <translation>Qmmp 欣赏历史插件</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../historyfactory.cpp" line="53"/>
         <source>This plugin collects information about listened tracks</source>
-        <translation>此插件收集已播放曲目的相关信息</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../historyfactory.cpp" line="54"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
-        <translation>作者：Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -55,7 +55,7 @@
     <message>
         <location filename="../historysettingsdialog.ui" line="14"/>
         <source>Listening History Plugin Settings</source>
-        <translation>欣赏历史插件设置</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../historysettingsdialog.ui" line="31"/>
@@ -69,58 +69,58 @@
         <location filename="../historywindow.ui" line="14"/>
         <location filename="../historywindow.ui" line="110"/>
         <source>History</source>
-        <translation>历史</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../historywindow.ui" line="29"/>
         <source>Time Range</source>
-        <translation>时间范围</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../historywindow.ui" line="35"/>
         <source>From:</source>
-        <translation>来自：</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../historywindow.ui" line="52"/>
         <source>To:</source>
-        <translation>到：</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../historywindow.ui" line="69"/>
         <source>Last week</source>
-        <translation>上周</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../historywindow.ui" line="76"/>
         <source>Last month</source>
-        <translation>上月</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../historywindow.ui" line="83"/>
         <source>Execute</source>
-        <translation>执行</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../historywindow.ui" line="129"/>
         <source>Time</source>
-        <translation>时间</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../historywindow.ui" line="134"/>
         <location filename="../historywindow.ui" line="183"/>
         <source>Song</source>
-        <translation>歌曲</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../historywindow.ui" line="143"/>
         <source>Distribution</source>
-        <translation>发布版本</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../historywindow.ui" line="156"/>
         <source>Day</source>
-        <translation>天</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../historywindow.ui" line="161"/>
@@ -128,17 +128,17 @@
         <location filename="../historywindow.ui" line="215"/>
         <location filename="../historywindow.ui" line="242"/>
         <source>Play counts</source>
-        <translation>播放次数</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../historywindow.ui" line="170"/>
         <source>Top Songs</source>
-        <translation>热门歌曲</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../historywindow.ui" line="197"/>
         <source>Top Artists</source>
-        <translation>热门艺术家</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../historywindow.ui" line="210"/>
@@ -148,7 +148,7 @@
     <message>
         <location filename="../historywindow.ui" line="224"/>
         <source>Top Genres</source>
-        <translation>热门流派</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../historywindow.ui" line="237"/>
@@ -156,39 +156,39 @@
         <translation>风格</translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="126"/>
+        <location filename="../historywindow.cpp" line="130"/>
         <source>dd MMMM yyyy</source>
-        <translation>dd MMMM yyyy</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="127"/>
+        <location filename="../historywindow.cpp" line="131"/>
         <source>hh:mm:ss</source>
-        <translation>hh:mm:ss</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="194"/>
+        <location filename="../historywindow.cpp" line="198"/>
         <source>MM-yyyy</source>
-        <translation>MM-yyyy</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="195"/>
+        <location filename="../historywindow.cpp" line="199"/>
         <source>dd MMMM</source>
-        <translation>dd MMMM</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="495"/>
+        <location filename="../historywindow.cpp" line="499"/>
         <source>Add to Playlist</source>
         <translation>添加到播放列表中</translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="496"/>
+        <location filename="../historywindow.cpp" line="500"/>
         <source>&amp;View Track Details</source>
         <translation>&amp;查看曲目详细内容</translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="498"/>
+        <location filename="../historywindow.cpp" line="502"/>
         <source>Remove from History</source>
-        <translation>从历史中移除</translation>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 </TS>
