@@ -19,7 +19,7 @@
     <message>
         <location filename="../history.cpp" line="58"/>
         <source>Alt+H</source>
-        <translation>Alt+H</translation>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -27,22 +27,22 @@
     <message>
         <location filename="../historyfactory.cpp" line="31"/>
         <source>Listening History Plugin</source>
-        <translation>聆聽歷史插件程式</translation>
+        <translation>聆聽歷史外掛程式</translation>
     </message>
     <message>
         <location filename="../historyfactory.cpp" line="51"/>
         <source>About Listening History Plugin</source>
-        <translation>關於聆聽歷史插件程式</translation>
+        <translation>關於聆聽歷史外掛程式</translation>
     </message>
     <message>
         <location filename="../historyfactory.cpp" line="52"/>
         <source>Qmmp Listening History Plugin</source>
-        <translation>Qmmp聆聽歷史插件程式</translation>
+        <translation>Qmmp 聆聽歷史外掛程式</translation>
     </message>
     <message>
         <location filename="../historyfactory.cpp" line="53"/>
         <source>This plugin collects information about listened tracks</source>
-        <translation>這個插件程式會收集關於聆聽音軌的資訊</translation>
+        <translation>這個外掛程式會收集關於聆聽音軌的資訊</translation>
     </message>
     <message>
         <location filename="../historyfactory.cpp" line="54"/>
@@ -55,7 +55,7 @@
     <message>
         <location filename="../historysettingsdialog.ui" line="14"/>
         <source>Listening History Plugin Settings</source>
-        <translation>聆聽歷史插件程式設定</translation>
+        <translation>聆聽歷史外掛程式設定</translation>
     </message>
     <message>
         <location filename="../historysettingsdialog.ui" line="31"/>
@@ -156,39 +156,39 @@
         <translation>流派</translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="126"/>
+        <location filename="../historywindow.cpp" line="130"/>
         <source>dd MMMM yyyy</source>
         <translation>dd MMMM yyyy</translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="127"/>
+        <location filename="../historywindow.cpp" line="131"/>
         <source>hh:mm:ss</source>
         <translation>hh:mm:ss</translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="194"/>
+        <location filename="../historywindow.cpp" line="198"/>
         <source>MM-yyyy</source>
         <translation>MM-yyyy</translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="195"/>
+        <location filename="../historywindow.cpp" line="199"/>
         <source>dd MMMM</source>
         <translation>dd MMMM</translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="495"/>
+        <location filename="../historywindow.cpp" line="499"/>
         <source>Add to Playlist</source>
-        <translation>新增到播放列表</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="496"/>
+        <location filename="../historywindow.cpp" line="500"/>
         <source>&amp;View Track Details</source>
-        <translation>&amp;查看曲目詳細信息</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../historywindow.cpp" line="498"/>
+        <location filename="../historywindow.cpp" line="502"/>
         <source>Remove from History</source>
-        <translation>從歷史記錄中刪除</translation>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 </TS>
