@@ -4,7 +4,7 @@
 <context>
     <name>KdeNotify</name>
     <message>
-        <location filename="../kdenotify.cpp" line="127"/>
+        <location filename="../kdenotify.cpp" line="120"/>
         <source>Qmmp now playing:</source>
         <translation>Qmmp joue&#xa0;:</translation>
     </message>
@@ -28,54 +28,54 @@
     </message>
 </context>
 <context>
-    <name>SettingsDialog</name>
+    <name>KdeNotifySettingsDialog</name>
     <message>
-        <location filename="../settingsdialog.ui" line="14"/>
-        <source>KDE 4 Notification Plugin Settings</source>
-        <translation>Réglages du greffon de notification KDE 4</translation>
+        <location filename="../kdenotifysettingsdialog.ui" line="14"/>
+        <source>KDE Notification Plugin Settings</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="39"/>
+        <location filename="../kdenotifysettingsdialog.ui" line="39"/>
         <source>Options</source>
         <translation>Options</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="45"/>
+        <location filename="../kdenotifysettingsdialog.ui" line="45"/>
         <source>Notification delay:</source>
         <translation>Délai des notifications:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="72"/>
-        <source>s</source>
-        <translation>s</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="52"/>
+        <location filename="../kdenotifysettingsdialog.ui" line="52"/>
         <source>Update visible notification instead create new</source>
         <translation>Mettre à jour la notification visible au lieu d&apos;en créer une nouvelle</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="85"/>
-        <source>Volume change notification</source>
-        <translation type="unfinished"></translation>
+        <location filename="../kdenotifysettingsdialog.ui" line="72"/>
+        <source>s</source>
+        <translation>s</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="95"/>
+        <location filename="../kdenotifysettingsdialog.ui" line="85"/>
+        <source>Volume change notification</source>
+        <translation>Notification de changement de volume</translation>
+    </message>
+    <message>
+        <location filename="../kdenotifysettingsdialog.ui" line="95"/>
         <source>Appearance</source>
         <translation>Apparence</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="101"/>
+        <location filename="../kdenotifysettingsdialog.ui" line="101"/>
         <source>Show covers</source>
         <translation>Montrer les couvertures</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="110"/>
+        <location filename="../kdenotifysettingsdialog.ui" line="110"/>
         <source>Edit template</source>
         <translation>Éditer le patron</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="77"/>
+        <location filename="../kdenotifysettingsdialog.cpp" line="76"/>
         <source>Notification Template</source>
         <translation>Patron de notification</translation>
     </message>
