@@ -200,7 +200,7 @@
     <message>
         <location filename="../librarywidget.cpp" line="52"/>
         <source>Replace Playlist</source>
-        <translation type="unfinished"></translation>
+        <translation>재생목록 바꾸기</translation>
     </message>
     <message>
         <location filename="../librarywidget.cpp" line="53"/>
