@@ -6,23 +6,23 @@
     <message>
         <location filename="../library.cpp" line="63"/>
         <source>Library</source>
-        <translation>媒体库</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../library.cpp" line="64"/>
         <source>Alt+L</source>
-        <translation>Alt+L</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../library.cpp" line="70"/>
         <source>Update library</source>
-        <translation>更新媒体库</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../library.cpp" line="192"/>
         <location filename="../library.cpp" line="193"/>
         <source>Unknown</source>
-        <translation>位置</translation>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -30,37 +30,37 @@
     <message>
         <location filename="../libraryfactory.cpp" line="33"/>
         <source>Media Library Plugin</source>
-        <translation>媒体库插件</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../libraryfactory.cpp" line="38"/>
         <source>Library</source>
-        <translation>媒体库</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../libraryfactory.cpp" line="38"/>
         <source>Ctrl+1</source>
-        <translation>Ctrl+1</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../libraryfactory.cpp" line="84"/>
         <source>About Media Library Plugin</source>
-        <translation>关于媒体库插件</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../libraryfactory.cpp" line="85"/>
         <source>Qmmp Media Library Plugin</source>
-        <translation>适用于 Qmmp 的媒体库插件</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../libraryfactory.cpp" line="86"/>
         <source>This plugin represents a database to store music files tags for a fast access</source>
-        <translation>该插件提供了一个用于存储音乐文件标签的数据库，以实现快速访问。</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../libraryfactory.cpp" line="87"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
-        <translation>作者：Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -71,85 +71,85 @@
         <translation>%1 - %2</translation>
     </message>
     <message>
-        <location filename="../librarymodel.cpp" line="356"/>
+        <location filename="../librarymodel.cpp" line="354"/>
         <source>Error</source>
         <translation>错误</translation>
     </message>
     <message>
-        <location filename="../librarymodel.cpp" line="356"/>
+        <location filename="../librarymodel.cpp" line="354"/>
         <source>Unable to connect to database</source>
-        <translation>无法连接到数据库</translation>
+        <translation type="unfinished"></translation>
+    </message>
+    <message numerus="yes">
+        <location filename="../librarymodel.cpp" line="375"/>
+        <source>%n day(s)</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <location filename="../librarymodel.cpp" line="376"/>
+        <source>%n hour(s)</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+        </translation>
     </message>
     <message numerus="yes">
         <location filename="../librarymodel.cpp" line="377"/>
-        <source>%n day(s)</source>
-        <translation>
-            <numerusform>%n 日</numerusform>
+        <source>%n minute(s)</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
         </translation>
     </message>
     <message numerus="yes">
         <location filename="../librarymodel.cpp" line="378"/>
-        <source>%n hour(s)</source>
-        <translation>
-            <numerusform>%n 小時</numerusform>
-        </translation>
-    </message>
-    <message numerus="yes">
-        <location filename="../librarymodel.cpp" line="379"/>
-        <source>%n minute(s)</source>
-        <translation>
-            <numerusform>%n 分钟</numerusform>
-        </translation>
-    </message>
-    <message numerus="yes">
-        <location filename="../librarymodel.cpp" line="380"/>
         <source>%n second(s)</source>
-        <translation>
-            <numerusform>%n 秒</numerusform>
+        <translation type="unfinished">
+            <numerusform></numerusform>
         </translation>
     </message>
+    <message>
+        <location filename="../librarymodel.cpp" line="382"/>
+        <source>%1 %2 %3 %4</source>
+        <comment>days hours minutes seconds</comment>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../librarymodel.cpp" line="384"/>
-        <source>%1 %2 %3 %4</source>
-        <comment>days hours minutes seconds</comment>
-        <translation>%1 %2 %3 %4</translation>
+        <source>%1 %2 %3</source>
+        <comment>hours minutes seconds</comment>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../librarymodel.cpp" line="386"/>
-        <source>%1 %2 %3</source>
-        <comment>hours minutes seconds</comment>
-        <translation>%1 %2 %3</translation>
-    </message>
-    <message>
-        <location filename="../librarymodel.cpp" line="388"/>
         <source>%1 %2</source>
         <comment>minutes seconds</comment>
-        <translation>%1 %2</translation>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../librarymodel.cpp" line="389"/>
+        <source>Number of tracks: &lt;b&gt;%1&lt;/b&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../librarymodel.cpp" line="390"/>
+        <source>Number of albums: &lt;b&gt;%1&lt;/b&gt;</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../librarymodel.cpp" line="391"/>
-        <source>Number of tracks: &lt;b&gt;%1&lt;/b&gt;</source>
-        <translation>音轨数： &lt;b&gt;%1&lt;/b&gt;</translation>
+        <source>Number of artists: &lt;b&gt;%1&lt;/b&gt;</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../librarymodel.cpp" line="392"/>
-        <source>Number of albums: &lt;b&gt;%1&lt;/b&gt;</source>
-        <translation>专辑数： &lt;b&gt;%1&lt;/b&gt;</translation>
-    </message>
-    <message>
-        <location filename="../librarymodel.cpp" line="393"/>
-        <source>Number of artists: &lt;b&gt;%1&lt;/b&gt;</source>
-        <translation>艺术家统计 &lt;b&gt;%1&lt;/b&gt;</translation>
-    </message>
-    <message>
-        <location filename="../librarymodel.cpp" line="394"/>
         <source>Total duration: &lt;b&gt;%1&lt;/b&gt;</source>
-        <translation>全部时长： &lt;b&gt;%1&lt;/b&gt;</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../librarymodel.cpp" line="397"/>
+        <location filename="../librarymodel.cpp" line="395"/>
         <source>Library Information</source>
-        <translation>媒体库信息</translation>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -157,17 +157,17 @@
     <message>
         <location filename="../librarysettingsdialog.ui" line="14"/>
         <source>Media Library Settings</source>
-        <translation>媒体库设置</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../librarysettingsdialog.ui" line="39"/>
         <source>Recreate database</source>
-        <translation>重建数据库</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../librarysettingsdialog.ui" line="46"/>
         <source>Show album year</source>
-        <translation>显示专辑年份</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../librarysettingsdialog.ui" line="55"/>
@@ -182,12 +182,12 @@
     <message>
         <location filename="../librarysettingsdialog.ui" line="95"/>
         <source>List of directories for scanning:</source>
-        <translation>待扫描目录列表：</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../librarysettingsdialog.cpp" line="65"/>
         <source>Select Directories for Scanning</source>
-        <translation>选择要扫描的目录</translation>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -195,12 +195,12 @@
     <message>
         <location filename="../librarywidget.cpp" line="51"/>
         <source>&amp;Add to Playlist</source>
-        <translation>添加到播放列表(&amp;A)</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../librarywidget.cpp" line="52"/>
         <source>Replace Playlist</source>
-        <translation>替换播放列表</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../librarywidget.cpp" line="53"/>
@@ -210,22 +210,22 @@
     <message>
         <location filename="../librarywidget.cpp" line="55"/>
         <source>Quick Search</source>
-        <translation>快捷搜索</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../librarywidget.cpp" line="56"/>
         <source>&amp;Library Information</source>
-        <translation>媒体库信息(&amp;L)</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../librarywidget.cpp" line="90"/>
         <source>Scanning directories...</source>
-        <translation>扫描目录中...</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../librarywidget.ui" line="14"/>
         <source>Media Library</source>
-        <translation>媒体库</translation>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 </TS>
