@@ -57,6 +57,19 @@
         <translation>Basado no Último script de letras por Vladimir Brkic &lt;vladimir_brkic@yahoo.com&gt;</translation>
     </message>
 </context>
+<context>
+    <name>LyricsSettingsDialog</name>
+    <message>
+        <location filename="../lyricssettingsdialog.ui" line="14"/>
+        <source>Lyrics Plugin Settings</source>
+        <translation>Preferencias do Engadido de Letras</translation>
+    </message>
+    <message>
+        <location filename="../lyricssettingsdialog.ui" line="29"/>
+        <source>Lyrics providers:</source>
+        <translation>Provedores de Letras:</translation>
+    </message>
+</context>
 <context>
     <name>LyricsWidget</name>
     <message>
@@ -95,54 +108,41 @@
         <translation>Ano:</translation>
     </message>
     <message>
-        <location filename="../lyricswidget.cpp" line="139"/>
-        <location filename="../lyricswidget.cpp" line="232"/>
+        <location filename="../lyricswidget.cpp" line="148"/>
+        <location filename="../lyricswidget.cpp" line="234"/>
         <source>&lt;h2&gt;%1 - %2&lt;/h2&gt;</source>
         <translation>&lt;h2&gt;%1 - %2&lt;/h2&gt;</translation>
     </message>
     <message>
-        <location filename="../lyricswidget.cpp" line="150"/>
+        <location filename="../lyricswidget.cpp" line="159"/>
         <source>Not found</source>
         <translation>Non atopada</translation>
     </message>
     <message>
-        <location filename="../lyricswidget.cpp" line="160"/>
+        <location filename="../lyricswidget.cpp" line="169"/>
         <source>Error: %1 - %2</source>
         <translation>Erro: %1 - %2</translation>
     </message>
     <message>
-        <location filename="../lyricswidget.cpp" line="173"/>
+        <location filename="../lyricswidget.cpp" line="182"/>
         <source>Receiving</source>
         <translation>Recibindo</translation>
     </message>
     <message>
-        <location filename="../lyricswidget.cpp" line="234"/>
+        <location filename="../lyricswidget.cpp" line="236"/>
         <source>Tag</source>
         <translation>Etiqueta</translation>
     </message>
     <message>
-        <location filename="../lyricswidget.cpp" line="255"/>
+        <location filename="../lyricswidget.cpp" line="257"/>
         <source>Cache</source>
         <translation>Cache</translation>
     </message>
 </context>
-<context>
-    <name>SettingsDialog</name>
-    <message>
-        <location filename="../settingsdialog.ui" line="14"/>
-        <source>Lyrics Plugin Settings</source>
-        <translation>Preferencias do Engadido de Letras</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="29"/>
-        <source>Lyrics providers:</source>
-        <translation>Provedores de Letras:</translation>
-    </message>
-</context>
 <context>
     <name>UltimateLyricsParser</name>
     <message>
-        <location filename="../ultimatelyricsparser.cpp" line="119"/>
+        <location filename="../ultimatelyricsparser.cpp" line="116"/>
         <source>%1 (line: %2)</source>
         <translation>%1 (liña: %2)</translation>
     </message>
