@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="ja_JP">
+<TS version="2.1" language="ja">
 <context>
     <name>Lyrics</name>
     <message>
@@ -57,12 +57,25 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>LyricsSettingsDialog</name>
+    <message>
+        <location filename="../lyricssettingsdialog.ui" line="14"/>
+        <source>Lyrics Plugin Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lyricssettingsdialog.ui" line="29"/>
+        <source>Lyrics providers:</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>LyricsWidget</name>
     <message>
         <location filename="../lyricswidget.ui" line="14"/>
         <source>Lyrics Plugin</source>
-        <translation type="unfinished">歌詞プラグイン</translation>
+        <translation>歌詞プラグイン</translation>
     </message>
     <message>
         <location filename="../lyricswidget.ui" line="31"/>
@@ -72,77 +85,64 @@
     <message>
         <location filename="../lyricswidget.ui" line="115"/>
         <source>Title:</source>
-        <translation type="unfinished">タイトル:</translation>
+        <translation>タイトル:</translation>
     </message>
     <message>
         <location filename="../lyricswidget.ui" line="132"/>
         <source>Album:</source>
-        <translation type="unfinished"></translation>
+        <translation>アルバム:</translation>
     </message>
     <message>
         <location filename="../lyricswidget.ui" line="142"/>
         <source>Artist:</source>
-        <translation type="unfinished">アーティスト:</translation>
+        <translation>アーティスト:</translation>
     </message>
     <message>
         <location filename="../lyricswidget.ui" line="159"/>
         <source>Track:</source>
-        <translation type="unfinished"></translation>
+        <translation>トラック:</translation>
     </message>
     <message>
         <location filename="../lyricswidget.ui" line="171"/>
         <source>Year:</source>
-        <translation type="unfinished"></translation>
+        <translation>年:</translation>
     </message>
     <message>
-        <location filename="../lyricswidget.cpp" line="139"/>
-        <location filename="../lyricswidget.cpp" line="232"/>
+        <location filename="../lyricswidget.cpp" line="148"/>
+        <location filename="../lyricswidget.cpp" line="234"/>
         <source>&lt;h2&gt;%1 - %2&lt;/h2&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lyricswidget.cpp" line="150"/>
+        <location filename="../lyricswidget.cpp" line="159"/>
         <source>Not found</source>
-        <translation type="unfinished">見付かりません</translation>
+        <translation>見付かりません</translation>
     </message>
     <message>
-        <location filename="../lyricswidget.cpp" line="160"/>
+        <location filename="../lyricswidget.cpp" line="169"/>
         <source>Error: %1 - %2</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lyricswidget.cpp" line="173"/>
+        <location filename="../lyricswidget.cpp" line="182"/>
         <source>Receiving</source>
-        <translation type="unfinished">取得中</translation>
+        <translation>取得中</translation>
     </message>
     <message>
-        <location filename="../lyricswidget.cpp" line="234"/>
+        <location filename="../lyricswidget.cpp" line="236"/>
         <source>Tag</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lyricswidget.cpp" line="255"/>
+        <location filename="../lyricswidget.cpp" line="257"/>
         <source>Cache</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>SettingsDialog</name>
-    <message>
-        <location filename="../settingsdialog.ui" line="14"/>
-        <source>Lyrics Plugin Settings</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="29"/>
-        <source>Lyrics providers:</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>UltimateLyricsParser</name>
     <message>
-        <location filename="../ultimatelyricsparser.cpp" line="119"/>
+        <location filename="../ultimatelyricsparser.cpp" line="116"/>
         <source>%1 (line: %2)</source>
         <translation type="unfinished"></translation>
     </message>
