@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2025 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -148,13 +148,13 @@ void Notifier::showMetaData()
 
 void Notifier::showVolume(int v)
 {
-    if ((m_volume != v) && m_showVolume)
+    if((m_volume != v) && m_showVolume)
     {
         if (m_volume >= 0 && !hasFullscreenWindow())
         {
             if (!m_popupWidget)
                 m_popupWidget = new PopupWidget();
-            m_popupWidget->showVolume(m_volume);
+            m_popupWidget->showVolume(v);
         }
         m_volume = v;
     }
