@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="ja_JP">
+<TS version="2.1" language="ja">
 <context>
     <name>NotifierFactory</name>
     <message>
@@ -25,105 +25,105 @@
     </message>
 </context>
 <context>
-    <name>PopupWidget</name>
+    <name>NotifierSettingsDialog</name>
     <message>
-        <location filename="../popupwidget.cpp" line="116"/>
-        <source>Volume:</source>
-        <translation>音量:</translation>
-    </message>
-</context>
-<context>
-    <name>SettingsDialog</name>
-    <message>
-        <location filename="../settingsdialog.ui" line="14"/>
+        <location filename="../notifiersettingsdialog.ui" line="14"/>
         <source>Notifier Plugin Settings</source>
         <translation>通知プラグイン設定</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="35"/>
+        <location filename="../notifiersettingsdialog.ui" line="35"/>
         <source>Desktop Notification</source>
         <translation>デスクトップ通知</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="361"/>
-        <source>Playback resume notification</source>
-        <translation>一時停止トラックの中途再生でも再度通知</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="368"/>
-        <source>Song change notification</source>
-        <translation>曲名通知</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="375"/>
-        <source>Disable notifications when another application is in the Full Screen Mode</source>
-        <translation>他のアプリケーションが全画面表示モードのときは通知をしません</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="378"/>
-        <source>Disable for full screen windows</source>
-        <translation>全画面表示中は抑止</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="325"/>
-        <source>Volume change notification</source>
-        <translation>音量変化通知</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="51"/>
+        <location filename="../notifiersettingsdialog.ui" line="51"/>
         <source>Font:</source>
         <translation>書体:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="332"/>
-        <source>Delay (ms):</source>
-        <translation>待ち時間 (ミリ秒):</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="85"/>
-        <source>Transparency:</source>
-        <translation>透明度:</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="251"/>
-        <source>Edit template</source>
-        <translation>ひな型を編集</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="78"/>
-        <location filename="../settingsdialog.ui" line="279"/>
-        <source>0</source>
-        <translation>0</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="229"/>
-        <source>Position</source>
-        <translation>位置</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="71"/>
+        <location filename="../notifiersettingsdialog.ui" line="71"/>
         <source>...</source>
         <translation>...</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="299"/>
+        <location filename="../notifiersettingsdialog.ui" line="78"/>
+        <location filename="../notifiersettingsdialog.ui" line="279"/>
+        <source>0</source>
+        <translation>0</translation>
+    </message>
+    <message>
+        <location filename="../notifiersettingsdialog.ui" line="85"/>
+        <source>Transparency:</source>
+        <translation>透明度:</translation>
+    </message>
+    <message>
+        <location filename="../notifiersettingsdialog.ui" line="229"/>
+        <source>Position</source>
+        <translation>配置</translation>
+    </message>
+    <message>
+        <location filename="../notifiersettingsdialog.ui" line="251"/>
+        <source>Edit template</source>
+        <translation>ひな型を編集</translation>
+    </message>
+    <message>
+        <location filename="../notifiersettingsdialog.ui" line="299"/>
         <source>Cover size:</source>
         <translation>表紙画像の大きさ:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="109"/>
-        <source>Notification Template</source>
-        <translation>通知のひな形</translation>
+        <location filename="../notifiersettingsdialog.ui" line="325"/>
+        <source>Volume change notification</source>
+        <translation>音量変化通知</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="388"/>
+        <location filename="../notifiersettingsdialog.ui" line="332"/>
+        <source>Delay (ms):</source>
+        <translation>待ち時間 (ミリ秒):</translation>
+    </message>
+    <message>
+        <location filename="../notifiersettingsdialog.ui" line="361"/>
+        <source>Playback resume notification</source>
+        <translation>一時停止トラックの中途再生でも再度通知</translation>
+    </message>
+    <message>
+        <location filename="../notifiersettingsdialog.ui" line="368"/>
+        <source>Song change notification</source>
+        <translation>曲名通知</translation>
+    </message>
+    <message>
+        <location filename="../notifiersettingsdialog.ui" line="375"/>
+        <source>Disable notifications when another application is in the Full Screen Mode</source>
+        <translation>他のアプリケーションが全画面表示モードのときは通知をしません</translation>
+    </message>
+    <message>
+        <location filename="../notifiersettingsdialog.ui" line="378"/>
+        <source>Disable for full screen windows</source>
+        <translation>全画面表示中は抑止</translation>
+    </message>
+    <message>
+        <location filename="../notifiersettingsdialog.ui" line="388"/>
         <source>Psi Notification</source>
         <translation>PSI 通知</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="400"/>
+        <location filename="../notifiersettingsdialog.ui" line="400"/>
         <source>Enable Psi notification</source>
         <translation>PSI 通知を有効にする</translation>
     </message>
+    <message>
+        <location filename="../notifiersettingsdialog.cpp" line="115"/>
+        <source>Notification Template</source>
+        <translation>通知のひな形</translation>
+    </message>
+</context>
+<context>
+    <name>PopupWidget</name>
+    <message>
+        <location filename="../popupwidget.cpp" line="115"/>
+        <source>Volume:</source>
+        <translation>音量:</translation>
+    </message>
 </context>
 </TS>
