@@ -29,6 +29,44 @@
         <translation>Escrito por: LLya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
 </context>
+<context>
+    <name>RDetectSettingsDialog</name>
+    <message>
+        <location filename="../rdetectsettingsdialog.ui" line="14"/>
+        <source>Volume Detection Plugin Settings</source>
+        <translation>Preferencias do engadido Detección de volume</translation>
+    </message>
+    <message>
+        <location filename="../rdetectsettingsdialog.ui" line="29"/>
+        <source>CD Audio Detection</source>
+        <translation>Detección de CD de audio</translation>
+    </message>
+    <message>
+        <location filename="../rdetectsettingsdialog.ui" line="38"/>
+        <source>Add tracks to playlist automatically</source>
+        <translation>Engadir pistas á lista de reprodución automaticamente</translation>
+    </message>
+    <message>
+        <location filename="../rdetectsettingsdialog.ui" line="45"/>
+        <source>Remove tracks from playlist automatically</source>
+        <translation>Eliminar pistas da lista de reprodución automaticamente</translation>
+    </message>
+    <message>
+        <location filename="../rdetectsettingsdialog.ui" line="55"/>
+        <source>Removable Device Detection</source>
+        <translation>Detección de dispositivos extraíbles</translation>
+    </message>
+    <message>
+        <location filename="../rdetectsettingsdialog.ui" line="64"/>
+        <source>Add files to playlist automatically</source>
+        <translation>Engadir ficheiros á lista de reprodución automaticamente</translation>
+    </message>
+    <message>
+        <location filename="../rdetectsettingsdialog.ui" line="71"/>
+        <source>Remove files from playlist automatically</source>
+        <translation>Eliminar ficheiros da lista de reprodución automaticamente</translation>
+    </message>
+</context>
 <context>
     <name>RemovableHelper</name>
     <message>
@@ -42,42 +80,4 @@
         <translation>Engadir volume &quot;%1&quot;</translation>
     </message>
 </context>
-<context>
-    <name>SettingsDialog</name>
-    <message>
-        <location filename="../settingsdialog.ui" line="14"/>
-        <source>Volume Detection Plugin Settings</source>
-        <translation>Preferencias do engadido Detección de volume</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="29"/>
-        <source>CD Audio Detection</source>
-        <translation>Detección de CD de audio</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="38"/>
-        <source>Add tracks to playlist automatically</source>
-        <translation>Engadir pistas á lista de reprodución automaticamente</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="45"/>
-        <source>Remove tracks from playlist automatically</source>
-        <translation>Eliminar pistas da lista de reprodución automaticamente</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="55"/>
-        <source>Removable Device Detection</source>
-        <translation>Detección de dispositivos extraíbles</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="64"/>
-        <source>Add files to playlist automatically</source>
-        <translation>Engadir ficheiros á lista de reprodución automaticamente</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="71"/>
-        <source>Remove files from playlist automatically</source>
-        <translation>Eliminar ficheiros da lista de reprodución automaticamente</translation>
-    </message>
-</context>
 </TS>
