@@ -1,32 +1,32 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="tr_TR">
+<TS version="2.1" language="tr">
 <context>
     <name>SleepInhibitFactory</name>
     <message>
         <location filename="../sleepinhibitorfactory.cpp" line="28"/>
         <source>Sleep Mode Inhibition Plugin</source>
-        <translation type="unfinished"></translation>
+        <translation>Uyku Modu Engelleme Eklentisi</translation>
     </message>
     <message>
         <location filename="../sleepinhibitorfactory.cpp" line="49"/>
         <source>About Sleep Mode Inhibit Plugin</source>
-        <translation type="unfinished"></translation>
+        <translation>Uyku Modu Engelle Eklentisi Hakkında</translation>
     </message>
     <message>
         <location filename="../sleepinhibitorfactory.cpp" line="50"/>
         <source>Qmmp Sleep Mode Inhibit Plugin</source>
-        <translation type="unfinished"></translation>
+        <translation>Qmmp Uyku Modu Engelle Eklentisi</translation>
     </message>
     <message>
         <location filename="../sleepinhibitorfactory.cpp" line="51"/>
         <source>This plugin inhibits sleep mode while audio playback</source>
-        <translation type="unfinished"></translation>
+        <translation>Bu eklenti ses oynatılırken uyku modunu engeller</translation>
     </message>
     <message>
         <location filename="../sleepinhibitorfactory.cpp" line="52"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>Yazan: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
 </context>
 </TS>
