@@ -1,114 +1,45 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="nl">
-<context>
-    <name>SettingsDialog</name>
-    <message>
-        <location filename="../settingsdialog.ui" line="14"/>
-        <source>Status Icon Plugin Settings</source>
-        <translation>Instellingen</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="29"/>
-        <source>Balloon message</source>
-        <translation>Ballonbericht</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="38"/>
-        <location filename="../settingsdialog.ui" line="105"/>
-        <source>Delay, ms:</source>
-        <translation>Vertraging, in ms:</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="79"/>
-        <source>Tooltip</source>
-        <translation>Hulpballon</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="91"/>
-        <source>Try to split file name when no tag</source>
-        <translation>Probeer de bestandsnaam te splitsen als er geen tag is</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="98"/>
-        <source>Show progress bar</source>
-        <translation>Voortgangsbalk tonen</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="131"/>
-        <source>Transparency:</source>
-        <translation>Doorzichtigheid:</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="165"/>
-        <source>0</source>
-        <translation>0</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="174"/>
-        <source>Cover size:</source>
-        <translation>Hoesgrootte:</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="214"/>
-        <source>32</source>
-        <translation>32</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="225"/>
-        <source>Edit template</source>
-        <translation>Sjabloon bewerken</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="250"/>
-        <source>Use standard icons</source>
-        <translation>Standaardpictogrammen gebruiken</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="80"/>
-        <source>Tooltip Template</source>
-        <translation>Hulpballon-sjabloon</translation>
-    </message>
-</context>
 <context>
     <name>StatusIcon</name>
     <message>
-        <location filename="../statusicon.cpp" line="71"/>
+        <location filename="../statusicon.cpp" line="70"/>
         <source>Play</source>
         <translation>Afspelen</translation>
     </message>
     <message>
-        <location filename="../statusicon.cpp" line="72"/>
+        <location filename="../statusicon.cpp" line="71"/>
         <source>Pause</source>
         <translation>Pauzeren</translation>
     </message>
     <message>
-        <location filename="../statusicon.cpp" line="73"/>
+        <location filename="../statusicon.cpp" line="72"/>
         <source>Stop</source>
         <translation>Stoppen</translation>
     </message>
     <message>
-        <location filename="../statusicon.cpp" line="75"/>
+        <location filename="../statusicon.cpp" line="74"/>
         <source>Next</source>
         <translation>Volgende</translation>
     </message>
     <message>
-        <location filename="../statusicon.cpp" line="76"/>
+        <location filename="../statusicon.cpp" line="75"/>
         <source>Previous</source>
         <translation>Vorige</translation>
     </message>
     <message>
-        <location filename="../statusicon.cpp" line="78"/>
+        <location filename="../statusicon.cpp" line="77"/>
         <source>Exit</source>
         <translation>Afsluiten</translation>
     </message>
     <message>
-        <location filename="../statusicon.cpp" line="120"/>
+        <location filename="../statusicon.cpp" line="119"/>
         <source>Stopped</source>
         <translation>Gestopt</translation>
     </message>
     <message>
-        <location filename="../statusicon.cpp" line="145"/>
+        <location filename="../statusicon.cpp" line="144"/>
         <source>Now Playing</source>
         <translation>Huidige nummer</translation>
     </message>
@@ -146,4 +77,73 @@
         <translation>Artur Guzik &lt;a.guzik88@gmail.com&gt;</translation>
     </message>
 </context>
+<context>
+    <name>StatusIconSettingsDialog</name>
+    <message>
+        <location filename="../statusiconsettingsdialog.ui" line="14"/>
+        <source>Status Icon Plugin Settings</source>
+        <translation>Instellingen</translation>
+    </message>
+    <message>
+        <location filename="../statusiconsettingsdialog.ui" line="29"/>
+        <source>Balloon message</source>
+        <translation>Ballonbericht</translation>
+    </message>
+    <message>
+        <location filename="../statusiconsettingsdialog.ui" line="38"/>
+        <location filename="../statusiconsettingsdialog.ui" line="105"/>
+        <source>Delay, ms:</source>
+        <translation>Vertraging, in ms:</translation>
+    </message>
+    <message>
+        <location filename="../statusiconsettingsdialog.ui" line="79"/>
+        <source>Tooltip</source>
+        <translation>Hulpballon</translation>
+    </message>
+    <message>
+        <location filename="../statusiconsettingsdialog.ui" line="91"/>
+        <source>Try to split file name when no tag</source>
+        <translation>Probeer de bestandsnaam te splitsen als er geen tag is</translation>
+    </message>
+    <message>
+        <location filename="../statusiconsettingsdialog.ui" line="98"/>
+        <source>Show progress bar</source>
+        <translation>Voortgangsbalk tonen</translation>
+    </message>
+    <message>
+        <location filename="../statusiconsettingsdialog.ui" line="131"/>
+        <source>Transparency:</source>
+        <translation>Doorzichtigheid:</translation>
+    </message>
+    <message>
+        <location filename="../statusiconsettingsdialog.ui" line="165"/>
+        <source>0</source>
+        <translation>0</translation>
+    </message>
+    <message>
+        <location filename="../statusiconsettingsdialog.ui" line="174"/>
+        <source>Cover size:</source>
+        <translation>Hoesgrootte:</translation>
+    </message>
+    <message>
+        <location filename="../statusiconsettingsdialog.ui" line="214"/>
+        <source>32</source>
+        <translation>32</translation>
+    </message>
+    <message>
+        <location filename="../statusiconsettingsdialog.ui" line="225"/>
+        <source>Edit template</source>
+        <translation>Sjabloon bewerken</translation>
+    </message>
+    <message>
+        <location filename="../statusiconsettingsdialog.ui" line="250"/>
+        <source>Use standard icons</source>
+        <translation>Standaardpictogrammen gebruiken</translation>
+    </message>
+    <message>
+        <location filename="../statusiconsettingsdialog.cpp" line="85"/>
+        <source>Tooltip Template</source>
+        <translation>Hulpballon-sjabloon</translation>
+    </message>
+</context>
 </TS>
