@@ -1,114 +1,45 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="pl_PL">
-<context>
-    <name>SettingsDialog</name>
-    <message>
-        <location filename="../settingsdialog.ui" line="14"/>
-        <source>Status Icon Plugin Settings</source>
-        <translation>Ustawienia wtyczki Ikona statusu</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="29"/>
-        <source>Balloon message</source>
-        <translation>Pokaż dymek</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="38"/>
-        <location filename="../settingsdialog.ui" line="105"/>
-        <source>Delay, ms:</source>
-        <translation>Opóźnienie, ms:</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="79"/>
-        <source>Tooltip</source>
-        <translation>Podpowiedź</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="91"/>
-        <source>Try to split file name when no tag</source>
-        <translation>Próbuj rozdzielić nazwę pliku, jeśli brakuje tagu</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="98"/>
-        <source>Show progress bar</source>
-        <translation>Pokaż pasek postępu</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="131"/>
-        <source>Transparency:</source>
-        <translation>Przezroczystość:</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="165"/>
-        <source>0</source>
-        <translation>0</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="174"/>
-        <source>Cover size:</source>
-        <translation>Wielkość okładki:</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="214"/>
-        <source>32</source>
-        <translation>32</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="225"/>
-        <source>Edit template</source>
-        <translation>Edytuj szablon</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="250"/>
-        <source>Use standard icons</source>
-        <translation>Użyj standardowych ikon</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="80"/>
-        <source>Tooltip Template</source>
-        <translation>Szablon podpowiedzi</translation>
-    </message>
-</context>
 <context>
     <name>StatusIcon</name>
     <message>
-        <location filename="../statusicon.cpp" line="71"/>
+        <location filename="../statusicon.cpp" line="70"/>
         <source>Play</source>
         <translation>Odtwarzaj</translation>
     </message>
     <message>
-        <location filename="../statusicon.cpp" line="72"/>
+        <location filename="../statusicon.cpp" line="71"/>
         <source>Pause</source>
         <translation>Pauza</translation>
     </message>
     <message>
-        <location filename="../statusicon.cpp" line="73"/>
+        <location filename="../statusicon.cpp" line="72"/>
         <source>Stop</source>
         <translation>Zatrzymaj</translation>
     </message>
     <message>
-        <location filename="../statusicon.cpp" line="75"/>
+        <location filename="../statusicon.cpp" line="74"/>
         <source>Next</source>
         <translation>Następny</translation>
     </message>
     <message>
-        <location filename="../statusicon.cpp" line="76"/>
+        <location filename="../statusicon.cpp" line="75"/>
         <source>Previous</source>
         <translation>Poprzedni</translation>
     </message>
     <message>
-        <location filename="../statusicon.cpp" line="78"/>
+        <location filename="../statusicon.cpp" line="77"/>
         <source>Exit</source>
         <translation>Wyjdź</translation>
     </message>
     <message>
-        <location filename="../statusicon.cpp" line="120"/>
+        <location filename="../statusicon.cpp" line="119"/>
         <source>Stopped</source>
         <translation>Zatrzymane</translation>
     </message>
     <message>
-        <location filename="../statusicon.cpp" line="145"/>
+        <location filename="../statusicon.cpp" line="144"/>
         <source>Now Playing</source>
         <translation>Teraz odtwarza</translation>
     </message>
@@ -146,4 +77,73 @@
         <translation>Artur Guzik &lt;a.guzik88@gmail.com&gt;</translation>
     </message>
 </context>
+<context>
+    <name>StatusIconSettingsDialog</name>
+    <message>
+        <location filename="../statusiconsettingsdialog.ui" line="14"/>
+        <source>Status Icon Plugin Settings</source>
+        <translation>Ustawienia wtyczki Ikona statusu</translation>
+    </message>
+    <message>
+        <location filename="../statusiconsettingsdialog.ui" line="29"/>
+        <source>Balloon message</source>
+        <translation>Pokaż dymek</translation>
+    </message>
+    <message>
+        <location filename="../statusiconsettingsdialog.ui" line="38"/>
+        <location filename="../statusiconsettingsdialog.ui" line="105"/>
+        <source>Delay, ms:</source>
+        <translation>Opóźnienie, ms:</translation>
+    </message>
+    <message>
+        <location filename="../statusiconsettingsdialog.ui" line="79"/>
+        <source>Tooltip</source>
+        <translation>Podpowiedź</translation>
+    </message>
+    <message>
+        <location filename="../statusiconsettingsdialog.ui" line="91"/>
+        <source>Try to split file name when no tag</source>
+        <translation>Próbuj rozdzielić nazwę pliku, jeśli brakuje tagu</translation>
+    </message>
+    <message>
+        <location filename="../statusiconsettingsdialog.ui" line="98"/>
+        <source>Show progress bar</source>
+        <translation>Pokaż pasek postępu</translation>
+    </message>
+    <message>
+        <location filename="../statusiconsettingsdialog.ui" line="131"/>
+        <source>Transparency:</source>
+        <translation>Przezroczystość:</translation>
+    </message>
+    <message>
+        <location filename="../statusiconsettingsdialog.ui" line="165"/>
+        <source>0</source>
+        <translation>0</translation>
+    </message>
+    <message>
+        <location filename="../statusiconsettingsdialog.ui" line="174"/>
+        <source>Cover size:</source>
+        <translation>Rozmiar okładki:</translation>
+    </message>
+    <message>
+        <location filename="../statusiconsettingsdialog.ui" line="214"/>
+        <source>32</source>
+        <translation>32</translation>
+    </message>
+    <message>
+        <location filename="../statusiconsettingsdialog.ui" line="225"/>
+        <source>Edit template</source>
+        <translation>Edytuj szablon</translation>
+    </message>
+    <message>
+        <location filename="../statusiconsettingsdialog.ui" line="250"/>
+        <source>Use standard icons</source>
+        <translation>Użyj standardowych ikon</translation>
+    </message>
+    <message>
+        <location filename="../statusiconsettingsdialog.cpp" line="85"/>
+        <source>Tooltip Template</source>
+        <translation>Szablon podpowiedzi</translation>
+    </message>
+</context>
 </TS>
