@@ -1,114 +1,45 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="zh_TW">
-<context>
-    <name>SettingsDialog</name>
-    <message>
-        <location filename="../settingsdialog.ui" line="14"/>
-        <source>Status Icon Plugin Settings</source>
-        <translation>狀態圖像插件設定</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="29"/>
-        <source>Balloon message</source>
-        <translation>气球通知</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="38"/>
-        <location filename="../settingsdialog.ui" line="105"/>
-        <source>Delay, ms:</source>
-        <translation>延遲 [ms]：</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="79"/>
-        <source>Tooltip</source>
-        <translation>工具提示</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="91"/>
-        <source>Try to split file name when no tag</source>
-        <translation>無標籤時嘗試拆分文件名</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="98"/>
-        <source>Show progress bar</source>
-        <translation>顯示進度條</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="131"/>
-        <source>Transparency:</source>
-        <translation>透明度：</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="165"/>
-        <source>0</source>
-        <translation>0</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="174"/>
-        <source>Cover size:</source>
-        <translation>封面大小：</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="214"/>
-        <source>32</source>
-        <translation type="unfinished">32</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="225"/>
-        <source>Edit template</source>
-        <translation>編輯模板</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="250"/>
-        <source>Use standard icons</source>
-        <translation>使用標准圖標</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="80"/>
-        <source>Tooltip Template</source>
-        <translation>工具提示模板</translation>
-    </message>
-</context>
 <context>
     <name>StatusIcon</name>
     <message>
-        <location filename="../statusicon.cpp" line="71"/>
+        <location filename="../statusicon.cpp" line="70"/>
         <source>Play</source>
         <translation>播放</translation>
     </message>
     <message>
-        <location filename="../statusicon.cpp" line="72"/>
+        <location filename="../statusicon.cpp" line="71"/>
         <source>Pause</source>
         <translation>暫停</translation>
     </message>
     <message>
-        <location filename="../statusicon.cpp" line="73"/>
+        <location filename="../statusicon.cpp" line="72"/>
         <source>Stop</source>
         <translation>停止</translation>
     </message>
     <message>
-        <location filename="../statusicon.cpp" line="75"/>
+        <location filename="../statusicon.cpp" line="74"/>
         <source>Next</source>
         <translation>下一曲</translation>
     </message>
     <message>
-        <location filename="../statusicon.cpp" line="76"/>
+        <location filename="../statusicon.cpp" line="75"/>
         <source>Previous</source>
         <translation>上一曲</translation>
     </message>
     <message>
-        <location filename="../statusicon.cpp" line="78"/>
+        <location filename="../statusicon.cpp" line="77"/>
         <source>Exit</source>
         <translation>結束</translation>
     </message>
     <message>
-        <location filename="../statusicon.cpp" line="120"/>
+        <location filename="../statusicon.cpp" line="119"/>
         <source>Stopped</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../statusicon.cpp" line="145"/>
+        <location filename="../statusicon.cpp" line="144"/>
         <source>Now Playing</source>
         <translation>正在播放</translation>
     </message>
@@ -146,4 +77,73 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>StatusIconSettingsDialog</name>
+    <message>
+        <location filename="../statusiconsettingsdialog.ui" line="14"/>
+        <source>Status Icon Plugin Settings</source>
+        <translation>狀態圖像插件設定</translation>
+    </message>
+    <message>
+        <location filename="../statusiconsettingsdialog.ui" line="29"/>
+        <source>Balloon message</source>
+        <translation>气球通知</translation>
+    </message>
+    <message>
+        <location filename="../statusiconsettingsdialog.ui" line="38"/>
+        <location filename="../statusiconsettingsdialog.ui" line="105"/>
+        <source>Delay, ms:</source>
+        <translation>延遲 [ms]：</translation>
+    </message>
+    <message>
+        <location filename="../statusiconsettingsdialog.ui" line="79"/>
+        <source>Tooltip</source>
+        <translation>工具提示</translation>
+    </message>
+    <message>
+        <location filename="../statusiconsettingsdialog.ui" line="91"/>
+        <source>Try to split file name when no tag</source>
+        <translation>無標籤時嘗試拆分文件名</translation>
+    </message>
+    <message>
+        <location filename="../statusiconsettingsdialog.ui" line="98"/>
+        <source>Show progress bar</source>
+        <translation>顯示進度條</translation>
+    </message>
+    <message>
+        <location filename="../statusiconsettingsdialog.ui" line="131"/>
+        <source>Transparency:</source>
+        <translation>透明度：</translation>
+    </message>
+    <message>
+        <location filename="../statusiconsettingsdialog.ui" line="165"/>
+        <source>0</source>
+        <translation>0</translation>
+    </message>
+    <message>
+        <location filename="../statusiconsettingsdialog.ui" line="174"/>
+        <source>Cover size:</source>
+        <translation>封面大小：</translation>
+    </message>
+    <message>
+        <location filename="../statusiconsettingsdialog.ui" line="214"/>
+        <source>32</source>
+        <translation type="unfinished">32</translation>
+    </message>
+    <message>
+        <location filename="../statusiconsettingsdialog.ui" line="225"/>
+        <source>Edit template</source>
+        <translation>編輯模板</translation>
+    </message>
+    <message>
+        <location filename="../statusiconsettingsdialog.ui" line="250"/>
+        <source>Use standard icons</source>
+        <translation>使用標准圖標</translation>
+    </message>
+    <message>
+        <location filename="../statusiconsettingsdialog.cpp" line="85"/>
+        <source>Tooltip Template</source>
+        <translation>工具提示模板</translation>
+    </message>
+</context>
 </TS>
