@@ -28,5 +28,25 @@
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
         <translation>Ditulis oleh: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
+    <message>
+        <location filename="../taskbarfactory.cpp" line="53"/>
+        <source>Based on QtWinExtras module of the Qt Toolkit</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../taskbarfactory.cpp" line="54"/>
+        <source>QtWinExtras developers:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../taskbarfactory.cpp" line="55"/>
+        <source>Ivan Vizir &lt;define-true-false@yandex.com&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../taskbarfactory.cpp" line="56"/>
+        <source>The Qt Company Ltd.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
