@@ -2,89 +2,94 @@
 <!DOCTYPE TS>
 <TS version="2.1" language="fr">
 <context>
-    <name>DecoderCDAudioFactory</name>
+    <name>CDAudioSettingsDialog</name>
     <message>
-        <location filename="../decodercdaudiofactory.cpp" line="50"/>
-        <source>CD Audio Plugin</source>
-        <translation>Greffon CD audio</translation>
-    </message>
-    <message>
-        <location filename="../decodercdaudiofactory.cpp" line="97"/>
-        <source>About CD Audio Plugin</source>
-        <translation>À propos du greffon CD audio</translation>
-    </message>
-    <message>
-        <location filename="../decodercdaudiofactory.cpp" line="98"/>
-        <source>Qmmp CD Audio Plugin</source>
-        <translation>Greffon CD audio pour Qmmp</translation>
-    </message>
-    <message>
-        <location filename="../decodercdaudiofactory.cpp" line="99"/>
-        <source>Compiled against libcdio-%1 and libcddb-%2</source>
-        <translation>Compilé contre libcdio-%1 et libcddb-%2</translation>
-    </message>
-    <message>
-        <location filename="../decodercdaudiofactory.cpp" line="101"/>
-        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
-        <translation>Écrit par : Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
-    </message>
-    <message>
-        <location filename="../decodercdaudiofactory.cpp" line="102"/>
-        <source>Usage: open cdda:/// using Add URL dialog or command line</source>
-        <translation>Utilisation&#xa0;: ouvrir cdda:/// avec le dialogue «&#xa0;Ajouter URL&#xa0;» ou en ligne de commande</translation>
-    </message>
-</context>
-<context>
-    <name>SettingsDialog</name>
-    <message>
-        <location filename="../settingsdialog.ui" line="14"/>
+        <location filename="../cdaudiosettingsdialog.ui" line="14"/>
         <source>CD Audio Plugin Settings</source>
         <translation>Configuration du greffon CD audio</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="29"/>
+        <location filename="../cdaudiosettingsdialog.ui" line="139"/>
         <source>Override device:</source>
         <translation>Surcharger le périphérique&#xa0;:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="42"/>
+        <location filename="../cdaudiosettingsdialog.ui" line="129"/>
         <source>Limit cd speed:</source>
         <translation>Limiter la vitesse du CD&#xa0;:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="62"/>
+        <location filename="../cdaudiosettingsdialog.ui" line="122"/>
         <source>Use cd-text</source>
         <translation>Utiliser CD-Text&#xa0;:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="69"/>
+        <location filename="../cdaudiosettingsdialog.ui" line="39"/>
         <source>CDDB</source>
         <translation>CDDB</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="78"/>
+        <location filename="../cdaudiosettingsdialog.ui" line="48"/>
         <source>Use HTTP instead of CDDBP</source>
         <translation>Utiliser HTTP au lieu de CDDBP</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="88"/>
+        <location filename="../cdaudiosettingsdialog.ui" line="58"/>
         <source>Server:</source>
         <translation>Serveur&#xa0;:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="95"/>
+        <location filename="../cdaudiosettingsdialog.ui" line="65"/>
         <source>Path:</source>
         <translation>Chemin&#xa0;:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="105"/>
+        <location filename="../cdaudiosettingsdialog.ui" line="75"/>
         <source>Port:</source>
         <translation>Port&#xa0;:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="117"/>
+        <location filename="../cdaudiosettingsdialog.ui" line="87"/>
         <source>Clear CDDB cache</source>
         <translation>Effacer le cache CDDB</translation>
     </message>
 </context>
+<context>
+    <name>DecoderCDAudioFactory</name>
+    <message>
+        <location filename="../decodercdaudiofactory.cpp" line="52"/>
+        <source>CD Audio Plugin</source>
+        <translation>Greffon CD audio</translation>
+    </message>
+    <message>
+        <location filename="../decodercdaudiofactory.cpp" line="98"/>
+        <source>About CD Audio Plugin</source>
+        <translation>À propos du greffon CD audio</translation>
+    </message>
+    <message>
+        <location filename="../decodercdaudiofactory.cpp" line="99"/>
+        <source>Qmmp CD Audio Plugin</source>
+        <translation>Greffon CD audio pour Qmmp</translation>
+    </message>
+    <message>
+        <location filename="../decodercdaudiofactory.cpp" line="101"/>
+        <source>Compiled against libcdio-%1 and libcddb-%2</source>
+        <translation>Compilé contre libcdio-%1 et libcddb-%2</translation>
+    </message>
+    <message>
+        <location filename="../decodercdaudiofactory.cpp" line="104"/>
+        <source>Compiled against libcdio-%1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../decodercdaudiofactory.cpp" line="107"/>
+        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
+        <translation>Écrit par : Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
+    </message>
+    <message>
+        <location filename="../decodercdaudiofactory.cpp" line="108"/>
+        <source>Usage: open cdda:/// using Add URL dialog or command line</source>
+        <translation>Utilisation&#xa0;: ouvrir cdda:/// avec le dialogue «&#xa0;Ajouter URL&#xa0;» ou en ligne de commande</translation>
+    </message>
+</context>
 </TS>
