@@ -2,89 +2,94 @@
 <!DOCTYPE TS>
 <TS version="2.1" language="zh_TW">
 <context>
-    <name>DecoderCDAudioFactory</name>
+    <name>CDAudioSettingsDialog</name>
     <message>
-        <location filename="../decodercdaudiofactory.cpp" line="50"/>
-        <source>CD Audio Plugin</source>
-        <translation>CD 聲訊插件</translation>
-    </message>
-    <message>
-        <location filename="../decodercdaudiofactory.cpp" line="97"/>
-        <source>About CD Audio Plugin</source>
-        <translation>關於 CD 聲訊插件</translation>
-    </message>
-    <message>
-        <location filename="../decodercdaudiofactory.cpp" line="98"/>
-        <source>Qmmp CD Audio Plugin</source>
-        <translation>Qmmp CD 聲訊插件</translation>
-    </message>
-    <message>
-        <location filename="../decodercdaudiofactory.cpp" line="99"/>
-        <source>Compiled against libcdio-%1 and libcddb-%2</source>
-        <translation>編譯依賴 libcdio-%1 and libcddb-%2</translation>
-    </message>
-    <message>
-        <location filename="../decodercdaudiofactory.cpp" line="101"/>
-        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
-        <translation>撰寫：Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
-    </message>
-    <message>
-        <location filename="../decodercdaudiofactory.cpp" line="102"/>
-        <source>Usage: open cdda:/// using Add URL dialog or command line</source>
-        <translation>用法：open cdda:/// 使用添加 URL會話或命令行</translation>
-    </message>
-</context>
-<context>
-    <name>SettingsDialog</name>
-    <message>
-        <location filename="../settingsdialog.ui" line="14"/>
+        <location filename="../cdaudiosettingsdialog.ui" line="14"/>
         <source>CD Audio Plugin Settings</source>
         <translation>CD 聲訊插件設置</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="29"/>
+        <location filename="../cdaudiosettingsdialog.ui" line="139"/>
         <source>Override device:</source>
         <translation>忽略設備：</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="42"/>
+        <location filename="../cdaudiosettingsdialog.ui" line="129"/>
         <source>Limit cd speed:</source>
         <translation>限制 CD 速度：</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="62"/>
+        <location filename="../cdaudiosettingsdialog.ui" line="122"/>
         <source>Use cd-text</source>
         <translation>使用 cd-text</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="69"/>
+        <location filename="../cdaudiosettingsdialog.ui" line="39"/>
         <source>CDDB</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="78"/>
+        <location filename="../cdaudiosettingsdialog.ui" line="48"/>
         <source>Use HTTP instead of CDDBP</source>
         <translation>使用 HTTP 而非 CDDBP</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="88"/>
+        <location filename="../cdaudiosettingsdialog.ui" line="58"/>
         <source>Server:</source>
         <translation>服務器：</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="95"/>
+        <location filename="../cdaudiosettingsdialog.ui" line="65"/>
         <source>Path:</source>
         <translation>路徑：</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="105"/>
+        <location filename="../cdaudiosettingsdialog.ui" line="75"/>
         <source>Port:</source>
         <translation>端口：</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="117"/>
+        <location filename="../cdaudiosettingsdialog.ui" line="87"/>
         <source>Clear CDDB cache</source>
         <translation>清除 CDDB 緩存</translation>
     </message>
 </context>
+<context>
+    <name>DecoderCDAudioFactory</name>
+    <message>
+        <location filename="../decodercdaudiofactory.cpp" line="52"/>
+        <source>CD Audio Plugin</source>
+        <translation>CD 聲訊插件</translation>
+    </message>
+    <message>
+        <location filename="../decodercdaudiofactory.cpp" line="98"/>
+        <source>About CD Audio Plugin</source>
+        <translation>關於 CD 聲訊插件</translation>
+    </message>
+    <message>
+        <location filename="../decodercdaudiofactory.cpp" line="99"/>
+        <source>Qmmp CD Audio Plugin</source>
+        <translation>Qmmp CD 聲訊插件</translation>
+    </message>
+    <message>
+        <location filename="../decodercdaudiofactory.cpp" line="101"/>
+        <source>Compiled against libcdio-%1 and libcddb-%2</source>
+        <translation>編譯依賴 libcdio-%1 and libcddb-%2</translation>
+    </message>
+    <message>
+        <location filename="../decodercdaudiofactory.cpp" line="104"/>
+        <source>Compiled against libcdio-%1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../decodercdaudiofactory.cpp" line="107"/>
+        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
+        <translation>撰寫：Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
+    </message>
+    <message>
+        <location filename="../decodercdaudiofactory.cpp" line="108"/>
+        <source>Usage: open cdda:/// using Add URL dialog or command line</source>
+        <translation>用法：open cdda:/// 使用添加 URL會話或命令行</translation>
+    </message>
+</context>
 </TS>
