@@ -6,32 +6,32 @@
     <message>
         <location filename="../decoderffmpegfactory.cpp" line="144"/>
         <source>FFmpeg Plugin</source>
-        <translation>FFmpeg 插件</translation>
+        <translation>FFmpeg 外掛</translation>
     </message>
     <message>
-        <location filename="../decoderffmpegfactory.cpp" line="150"/>
+        <location filename="../decoderffmpegfactory.cpp" line="146"/>
         <source>FFmpeg Formats</source>
         <translation>FFmpeg 格式</translation>
     </message>
     <message>
-        <location filename="../decoderffmpegfactory.cpp" line="344"/>
+        <location filename="../decoderffmpegfactory.cpp" line="340"/>
         <source>About FFmpeg Audio Plugin</source>
         <translation>關於 FFmpeg 聲訊插件</translation>
     </message>
     <message>
-        <location filename="../decoderffmpegfactory.cpp" line="345"/>
+        <location filename="../decoderffmpegfactory.cpp" line="341"/>
         <source>Qmmp FFmpeg Audio Plugin</source>
         <translation>Qmmp FFmpeg 聲訊插件</translation>
     </message>
     <message>
-        <location filename="../decoderffmpegfactory.cpp" line="346"/>
+        <location filename="../decoderffmpegfactory.cpp" line="342"/>
         <source>Compiled against:</source>
         <translation>編譯使用：</translation>
     </message>
     <message>
-        <location filename="../decoderffmpegfactory.cpp" line="359"/>
+        <location filename="../decoderffmpegfactory.cpp" line="355"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
-        <translation>作者：Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
+        <translation>撰寫：Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
 </context>
 <context>
@@ -49,72 +49,72 @@
     <message>
         <location filename="../ffmpegsettingsdialog.ui" line="61"/>
         <source>Windows Media Audio</source>
-        <translation>Windows Media Audio</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../ffmpegsettingsdialog.ui" line="68"/>
         <source>Monkey&apos;s Audio (APE)</source>
-        <translation>Windows Media Audio</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../ffmpegsettingsdialog.ui" line="75"/>
         <source>True Audio</source>
-        <translation>Windows Media Audio</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../ffmpegsettingsdialog.ui" line="82"/>
         <source>ADTS AAC</source>
-        <translation>ADTS AAC</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../ffmpegsettingsdialog.ui" line="89"/>
         <source>MP3 (MPEG audio layer 3)</source>
-        <translation>MP3 (MPEG audio layer 3)</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../ffmpegsettingsdialog.ui" line="96"/>
         <source>MPEG-4 AAC/ALAC</source>
-        <translation>MPEG-4 AAC/ALAC</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../ffmpegsettingsdialog.ui" line="103"/>
         <source>RealAudio 1.0/2.0</source>
-        <translation>RealAudio 1.0/2.0</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../ffmpegsettingsdialog.ui" line="110"/>
         <source>Shorten</source>
-        <translation>縮短</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../ffmpegsettingsdialog.ui" line="117"/>
         <source>AC3/EAC</source>
-        <translation>AC3/EAC</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../ffmpegsettingsdialog.ui" line="124"/>
         <source>DTS/DTS-Core</source>
-        <translation>DTS/DTS-Core</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../ffmpegsettingsdialog.ui" line="131"/>
         <source>Matroska Audio (Dolby TrueHD Lossless)</source>
-        <translation>Matroska Audio (Dolby TrueHD Lossless)</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../ffmpegsettingsdialog.ui" line="138"/>
         <source>VQF</source>
-        <translation>VQF</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../ffmpegsettingsdialog.ui" line="145"/>
         <source>Tom&apos;s lossless Audio Kompressor (TAK)</source>
-        <translation>Tom&apos;s lossless Audio Kompressor (TAK)</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../ffmpegsettingsdialog.ui" line="152"/>
         <source>Direct Stream Digital (DSD)</source>
-        <translation>Direct Stream Digital (DSD)</translation>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 </TS>
