@@ -4,55 +4,55 @@
 <context>
     <name>DecoderGmeFactory</name>
     <message>
-        <location filename="../decodergmefactory.cpp" line="38"/>
+        <location filename="../decodergmefactory.cpp" line="37"/>
         <source>GME Plugin</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../decodergmefactory.cpp" line="41"/>
+        <location filename="../decodergmefactory.cpp" line="42"/>
         <source>Game Music Files</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../decodergmefactory.cpp" line="103"/>
+        <location filename="../decodergmefactory.cpp" line="101"/>
         <source>About GME Audio Plugin</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../decodergmefactory.cpp" line="104"/>
+        <location filename="../decodergmefactory.cpp" line="102"/>
         <source>Qmmp GME Audio Plugin</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../decodergmefactory.cpp" line="105"/>
+        <location filename="../decodergmefactory.cpp" line="103"/>
         <source>This plugin uses Game_Music_Emu library to play game music files</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../decodergmefactory.cpp" line="106"/>
+        <location filename="../decodergmefactory.cpp" line="104"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
-    <name>SettingsDialog</name>
+    <name>GmeSettingsDialog</name>
     <message>
-        <location filename="../settingsdialog.ui" line="14"/>
+        <location filename="../gmesettingsdialog.ui" line="14"/>
         <source>GME Plugin Settings</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="34"/>
+        <location filename="../gmesettingsdialog.ui" line="34"/>
         <source>Fadeout length:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="44"/>
+        <location filename="../gmesettingsdialog.ui" line="44"/>
         <source>ms</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="57"/>
+        <location filename="../gmesettingsdialog.ui" line="57"/>
         <source>Enable fadeout</source>
         <translation type="unfinished"></translation>
     </message>
