@@ -2,44 +2,44 @@
 <!DOCTYPE TS>
 <TS version="2.1" language="zh_TW">
 <context>
-    <name>DecoderMPEGFactory</name>
+    <name>DecoderMpegFactory</name>
     <message>
-        <location filename="../decodermpegfactory.cpp" line="180"/>
+        <location filename="../decodermpegfactory.cpp" line="178"/>
         <source>MPEG Plugin</source>
         <translation>MPEG 外掛</translation>
     </message>
     <message>
-        <location filename="../decodermpegfactory.cpp" line="183"/>
+        <location filename="../decodermpegfactory.cpp" line="181"/>
         <source>MPEG Files</source>
         <translation>MPEG 檔案</translation>
     </message>
     <message>
-        <location filename="../decodermpegfactory.cpp" line="421"/>
+        <location filename="../decodermpegfactory.cpp" line="417"/>
         <source>About MPEG Audio Plugin</source>
         <translation>關於 MPEG 聲訊插件</translation>
     </message>
     <message>
-        <location filename="../decodermpegfactory.cpp" line="422"/>
+        <location filename="../decodermpegfactory.cpp" line="418"/>
         <source>MPEG 1.0/2.0/2.5 layer 1/2/3 audio decoder</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../decodermpegfactory.cpp" line="423"/>
+        <location filename="../decodermpegfactory.cpp" line="419"/>
         <source>Compiled against:</source>
         <translation>編譯使用：</translation>
     </message>
     <message>
-        <location filename="../decodermpegfactory.cpp" line="432"/>
+        <location filename="../decodermpegfactory.cpp" line="428"/>
         <source>mpg123, API version: %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../decodermpegfactory.cpp" line="436"/>
+        <location filename="../decodermpegfactory.cpp" line="432"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
         <translation>程式編寫：Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
     <message>
-        <location filename="../decodermpegfactory.cpp" line="437"/>
+        <location filename="../decodermpegfactory.cpp" line="433"/>
         <source>Source code based on mq3 and madplay projects</source>
         <translation type="unfinished"></translation>
     </message>
@@ -71,104 +71,104 @@
     </message>
 </context>
 <context>
-    <name>SettingsDialog</name>
+    <name>MpegSettingsDialog</name>
     <message>
-        <location filename="../settingsdialog.ui" line="14"/>
+        <location filename="../mpegsettingsdialog.ui" line="14"/>
         <source>MPEG Plugin Settings</source>
         <translation>MPEG 插件設定</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="35"/>
+        <location filename="../mpegsettingsdialog.ui" line="35"/>
         <source>Decoder</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="41"/>
+        <location filename="../mpegsettingsdialog.ui" line="41"/>
         <source>MAD</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="48"/>
+        <location filename="../mpegsettingsdialog.ui" line="48"/>
         <source>MPG123</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="71"/>
+        <location filename="../mpegsettingsdialog.ui" line="71"/>
         <source>Enable CRC checking</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="87"/>
+        <location filename="../mpegsettingsdialog.ui" line="87"/>
         <source>Tag Priority</source>
         <translation>標簽優先</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="99"/>
+        <location filename="../mpegsettingsdialog.ui" line="99"/>
         <source>First:</source>
         <translation>第一：</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="119"/>
-        <location filename="../settingsdialog.ui" line="168"/>
-        <location filename="../settingsdialog.ui" line="217"/>
+        <location filename="../mpegsettingsdialog.ui" line="119"/>
+        <location filename="../mpegsettingsdialog.ui" line="168"/>
+        <location filename="../mpegsettingsdialog.ui" line="217"/>
         <source>ID3v1</source>
         <translation>ID3v1</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="124"/>
-        <location filename="../settingsdialog.ui" line="173"/>
-        <location filename="../settingsdialog.ui" line="222"/>
+        <location filename="../mpegsettingsdialog.ui" line="124"/>
+        <location filename="../mpegsettingsdialog.ui" line="173"/>
+        <location filename="../mpegsettingsdialog.ui" line="222"/>
         <source>ID3v2</source>
         <translation>ID3v2</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="129"/>
-        <location filename="../settingsdialog.ui" line="178"/>
-        <location filename="../settingsdialog.ui" line="227"/>
+        <location filename="../mpegsettingsdialog.ui" line="129"/>
+        <location filename="../mpegsettingsdialog.ui" line="178"/>
+        <location filename="../mpegsettingsdialog.ui" line="227"/>
         <source>APE</source>
         <translation>APE</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="134"/>
-        <location filename="../settingsdialog.ui" line="183"/>
-        <location filename="../settingsdialog.ui" line="232"/>
+        <location filename="../mpegsettingsdialog.ui" line="134"/>
+        <location filename="../mpegsettingsdialog.ui" line="183"/>
+        <location filename="../mpegsettingsdialog.ui" line="232"/>
         <source>Disabled</source>
         <translation>無效</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="148"/>
+        <location filename="../mpegsettingsdialog.ui" line="148"/>
         <source>Second:</source>
         <translation>第二：</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="197"/>
+        <location filename="../mpegsettingsdialog.ui" line="197"/>
         <source>Third:</source>
         <translation>第三：</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="253"/>
+        <location filename="../mpegsettingsdialog.ui" line="253"/>
         <source>Merge selected tag types</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="272"/>
+        <location filename="../mpegsettingsdialog.ui" line="272"/>
         <source>Encodings</source>
         <translation>編碼</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="333"/>
+        <location filename="../mpegsettingsdialog.ui" line="294"/>
+        <source>ID3v2 encoding:</source>
+        <translation>ID3v2 編碼：</translation>
+    </message>
+    <message>
+        <location filename="../mpegsettingsdialog.ui" line="333"/>
         <source>ID3v1 encoding:</source>
         <translation>ID3v1 編碼：</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="343"/>
+        <location filename="../mpegsettingsdialog.ui" line="343"/>
         <source>Try to detect encoding</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="294"/>
-        <source>ID3v2 encoding:</source>
-        <translation>ID3v2 編碼：</translation>
-    </message>
 </context>
 </TS>
