@@ -4,34 +4,34 @@
 <context>
     <name>DecoderSndFileFactory</name>
     <message>
-        <location filename="../decodersndfilefactory.cpp" line="123"/>
+        <location filename="../decodersndfilefactory.cpp" line="119"/>
         <source>Sndfile Plugin</source>
-        <translation>Sndfile插件</translation>
+        <translation>Sndfile 外掛</translation>
     </message>
     <message>
-        <location filename="../decodersndfilefactory.cpp" line="127"/>
+        <location filename="../decodersndfilefactory.cpp" line="123"/>
         <source>PCM Files</source>
         <translation>PCM 檔案</translation>
     </message>
     <message>
-        <location filename="../decodersndfilefactory.cpp" line="232"/>
+        <location filename="../decodersndfilefactory.cpp" line="228"/>
         <source>About Sndfile Audio Plugin</source>
         <translation>關於 Sndfile 聲訊插件</translation>
     </message>
     <message>
-        <location filename="../decodersndfilefactory.cpp" line="233"/>
+        <location filename="../decodersndfilefactory.cpp" line="229"/>
         <source>Qmmp Sndfile Audio Plugin</source>
         <translation>Qmmp Sndfile 聲訊插件</translation>
     </message>
     <message>
-        <location filename="../decodersndfilefactory.cpp" line="234"/>
+        <location filename="../decodersndfilefactory.cpp" line="230"/>
         <source>Compiled against %1</source>
-        <translation>編譯針對 %1 </translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../decodersndfilefactory.cpp" line="235"/>
+        <location filename="../decodersndfilefactory.cpp" line="231"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
-        <translation>作者：Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
+        <translation>撰寫：Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
 </context>
 </TS>
