@@ -4,32 +4,32 @@
 <context>
     <name>DecoderWavPackFactory</name>
     <message>
-        <location filename="../decoderwavpackfactory.cpp" line="39"/>
+        <location filename="../decoderwavpackfactory.cpp" line="38"/>
         <source>WavPack Plugin</source>
         <translation>Модуль WavPack</translation>
     </message>
     <message>
-        <location filename="../decoderwavpackfactory.cpp" line="41"/>
+        <location filename="../decoderwavpackfactory.cpp" line="40"/>
         <source>WavPack Files</source>
         <translation>Файлы WavPack</translation>
     </message>
     <message>
-        <location filename="../decoderwavpackfactory.cpp" line="183"/>
+        <location filename="../decoderwavpackfactory.cpp" line="180"/>
         <source>About WavPack Audio Plugin</source>
         <translation>Об аудио-модуле WavPack</translation>
     </message>
     <message>
-        <location filename="../decoderwavpackfactory.cpp" line="184"/>
+        <location filename="../decoderwavpackfactory.cpp" line="181"/>
         <source>Qmmp WavPack Audio Plugin</source>
         <translation>Аудио-модуль WavPack для Qmmp</translation>
     </message>
     <message>
-        <location filename="../decoderwavpackfactory.cpp" line="185"/>
-        <source>WavPack library version:</source>
-        <translation>Версия библиотеки WavPack:</translation>
+        <location filename="../decoderwavpackfactory.cpp" line="182"/>
+        <source>WavPack library version: %1</source>
+        <translation>Версия библиотеки WavPack: %1</translation>
     </message>
     <message>
-        <location filename="../decoderwavpackfactory.cpp" line="187"/>
+        <location filename="../decoderwavpackfactory.cpp" line="184"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
         <translation>Разработчик: Илья Котов &lt;forkotov02@ya.ru&gt;</translation>
     </message>
@@ -37,12 +37,12 @@
 <context>
     <name>WavPackMetaDataModel</name>
     <message>
-        <location filename="../wavpackmetadatamodel.cpp" line="72"/>
+        <location filename="../wavpackmetadatamodel.cpp" line="71"/>
         <source>Ratio</source>
         <translation>Сжатие</translation>
     </message>
     <message>
-        <location filename="../wavpackmetadatamodel.cpp" line="73"/>
+        <location filename="../wavpackmetadatamodel.cpp" line="72"/>
         <source>Version</source>
         <translation>Версия</translation>
     </message>
