@@ -9,148 +9,75 @@
         <translation>XMP-Modul</translation>
     </message>
     <message>
-        <location filename="../decoderxmpfactory.cpp" line="52"/>
+        <location filename="../decoderxmpfactory.cpp" line="54"/>
         <source>Module Files</source>
         <translation>Moduldateien</translation>
     </message>
     <message>
-        <location filename="../decoderxmpfactory.cpp" line="108"/>
+        <location filename="../decoderxmpfactory.cpp" line="109"/>
         <source>About XMP Audio Plugin</source>
         <translation>Über XMP-Audiomodul</translation>
     </message>
     <message>
-        <location filename="../decoderxmpfactory.cpp" line="109"/>
+        <location filename="../decoderxmpfactory.cpp" line="110"/>
         <source>Qmmp XMP Audio Plugin</source>
         <translation>Qmmp XMP-Audiomodul</translation>
     </message>
     <message>
-        <location filename="../decoderxmpfactory.cpp" line="110"/>
+        <location filename="../decoderxmpfactory.cpp" line="111"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
         <translation>Geschrieben von: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
     <message>
-        <location filename="../decoderxmpfactory.cpp" line="111"/>
+        <location filename="../decoderxmpfactory.cpp" line="112"/>
         <source>Compiled against libxmp-%1</source>
         <translation>Kompiliert gegen libxmp-%1</translation>
     </message>
 </context>
-<context>
-    <name>SettingsDialog</name>
-    <message>
-        <location filename="../settingsdialog.ui" line="14"/>
-        <source>XMP Plugin Settings</source>
-        <translation>XMP-Moduleinstellungen</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="34"/>
-        <source>Amplification factor:</source>
-        <translation>Verstärkungsfaktor:</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="51"/>
-        <source>Stereo mixing:</source>
-        <translation>Stereoabmischung:</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="68"/>
-        <source> Interpolation type:</source>
-        <translation> Interpolationstyp:</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="78"/>
-        <source>Lowpass filter effect</source>
-        <translation>Tiefpassfiltereffekt</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="85"/>
-        <source>Use vblank timing</source>
-        <translation>Vertikale Austastlückenabstimmung verwenden</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="92"/>
-        <source>Emulate Protracker 2.x FX9 bug</source>
-        <translation>Protracker 2.x FX9-Fehler emulieren</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="99"/>
-        <source>Sample rate:</source>
-        <translation>Abtastrate:</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="33"/>
-        <source>22050 Hz</source>
-        <translation>22050 Hz</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="34"/>
-        <source>44100 Hz</source>
-        <translation>44100 Hz</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="35"/>
-        <source>48000 Hz</source>
-        <translation>48000 Hz</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="36"/>
-        <source>Nearest neighbor</source>
-        <translation>Nächster Nachbar</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="37"/>
-        <source>Linear</source>
-        <translation>Linear</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="38"/>
-        <source>Cubic spline</source>
-        <translation>Kubischer Spline</translation>
-    </message>
-</context>
 <context>
     <name>XmpMetaDataModel</name>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="52"/>
+        <location filename="../xmpmetadatamodel.cpp" line="51"/>
         <source>Volume scale</source>
         <translation>Lautstärkenskalierung</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="53"/>
+        <location filename="../xmpmetadatamodel.cpp" line="52"/>
         <source>Number of patterns</source>
         <translation>Anzahl der Muster</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="54"/>
+        <location filename="../xmpmetadatamodel.cpp" line="53"/>
         <source>Number of tracks</source>
         <translation>Anzahl der Titel</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="55"/>
+        <location filename="../xmpmetadatamodel.cpp" line="54"/>
         <source>Tracks per pattern</source>
         <translation>Titel pro Muster</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="56"/>
+        <location filename="../xmpmetadatamodel.cpp" line="55"/>
         <source>Number of instruments</source>
         <translation>Anzahl der Instrumente</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="57"/>
+        <location filename="../xmpmetadatamodel.cpp" line="56"/>
         <source>Number of samples</source>
         <translation>Anzahl der Abtastwerte</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="58"/>
+        <location filename="../xmpmetadatamodel.cpp" line="57"/>
         <source>Initial speed</source>
         <translation>Anfangsgeschwindigkeit</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="59"/>
+        <location filename="../xmpmetadatamodel.cpp" line="58"/>
         <source>Initial BPM</source>
         <translation>Anfangs-BPM</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="60"/>
+        <location filename="../xmpmetadatamodel.cpp" line="59"/>
         <source>Module length in patterns</source>
         <translation>Modullänge in Muster</translation>
     </message>
@@ -170,4 +97,87 @@
         <translation>Kommentar</translation>
     </message>
 </context>
+<context>
+    <name>XmpSettingsDialog</name>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="14"/>
+        <source>XMP Plugin Settings</source>
+        <translation>XMP-Moduleinstellungen</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="34"/>
+        <source>Amplification factor:</source>
+        <translation>Verstärkungsfaktor:</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="51"/>
+        <source>Stereo mixing:</source>
+        <translation>Stereoabmischung:</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="68"/>
+        <source> Interpolation type:</source>
+        <translation> Interpolationstyp:</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="78"/>
+        <source>Lowpass filter effect</source>
+        <translation>Tiefpassfiltereffekt</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="85"/>
+        <source>Use vblank timing</source>
+        <translation>Vertikale Austastlückenabstimmung verwenden</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="92"/>
+        <source>Emulate Protracker 2.x FX9 bug</source>
+        <translation>Protracker 2.x FX9-Fehler emulieren</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="99"/>
+        <source>Sample rate:</source>
+        <translation>Abtastrate:</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="109"/>
+        <source>Emulate sample loop bug</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="116"/>
+        <source>Use Paula mixer in Amiga modules</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.cpp" line="33"/>
+        <source>22050 Hz</source>
+        <translation>22050 Hz</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.cpp" line="34"/>
+        <source>44100 Hz</source>
+        <translation>44100 Hz</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.cpp" line="35"/>
+        <source>48000 Hz</source>
+        <translation>48000 Hz</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.cpp" line="36"/>
+        <source>Nearest neighbor</source>
+        <translation>Nächster Nachbar</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.cpp" line="37"/>
+        <source>Linear</source>
+        <translation>Linear</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.cpp" line="38"/>
+        <source>Cubic spline</source>
+        <translation>Kubischer Spline</translation>
+    </message>
+</context>
 </TS>
