@@ -9,148 +9,75 @@
         <translation>Greffon XMP</translation>
     </message>
     <message>
-        <location filename="../decoderxmpfactory.cpp" line="52"/>
+        <location filename="../decoderxmpfactory.cpp" line="54"/>
         <source>Module Files</source>
         <translation>Fichiers Module</translation>
     </message>
     <message>
-        <location filename="../decoderxmpfactory.cpp" line="108"/>
+        <location filename="../decoderxmpfactory.cpp" line="109"/>
         <source>About XMP Audio Plugin</source>
         <translation>A propos du greffon audio XMP</translation>
     </message>
     <message>
-        <location filename="../decoderxmpfactory.cpp" line="109"/>
+        <location filename="../decoderxmpfactory.cpp" line="110"/>
         <source>Qmmp XMP Audio Plugin</source>
         <translation>Greffon audio XMP Qmmp</translation>
     </message>
     <message>
-        <location filename="../decoderxmpfactory.cpp" line="110"/>
+        <location filename="../decoderxmpfactory.cpp" line="111"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
         <translation>Écrit par : Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
     <message>
-        <location filename="../decoderxmpfactory.cpp" line="111"/>
+        <location filename="../decoderxmpfactory.cpp" line="112"/>
         <source>Compiled against libxmp-%1</source>
         <translation>Compilé avec libxmp-%1</translation>
     </message>
 </context>
-<context>
-    <name>SettingsDialog</name>
-    <message>
-        <location filename="../settingsdialog.ui" line="14"/>
-        <source>XMP Plugin Settings</source>
-        <translation>Paramètres du greffon XMP</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="34"/>
-        <source>Amplification factor:</source>
-        <translation>Facteur d&apos;amplification</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="51"/>
-        <source>Stereo mixing:</source>
-        <translation>Mixing Stéréo</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="68"/>
-        <source> Interpolation type:</source>
-        <translation>Type d&apos;interpolation</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="78"/>
-        <source>Lowpass filter effect</source>
-        <translation>Filtre avec effet lowpass</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="85"/>
-        <source>Use vblank timing</source>
-        <translation>Utiliser le timing vblank</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="92"/>
-        <source>Emulate Protracker 2.x FX9 bug</source>
-        <translation>Emuler le bug Protracker 2.x FX9</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="99"/>
-        <source>Sample rate:</source>
-        <translation>Taux du sample</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="33"/>
-        <source>22050 Hz</source>
-        <translation>22 050 Hz</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="34"/>
-        <source>44100 Hz</source>
-        <translation>44 100 Hz</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="35"/>
-        <source>48000 Hz</source>
-        <translation>48 000 Hz</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="36"/>
-        <source>Nearest neighbor</source>
-        <translation>Voisin le plus proche</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="37"/>
-        <source>Linear</source>
-        <translation>Linéaire</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="38"/>
-        <source>Cubic spline</source>
-        <translation>Spline cubique</translation>
-    </message>
-</context>
 <context>
     <name>XmpMetaDataModel</name>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="52"/>
+        <location filename="../xmpmetadatamodel.cpp" line="51"/>
         <source>Volume scale</source>
         <translation>Hauteur du volume</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="53"/>
+        <location filename="../xmpmetadatamodel.cpp" line="52"/>
         <source>Number of patterns</source>
         <translation>Nombre de patterns</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="54"/>
+        <location filename="../xmpmetadatamodel.cpp" line="53"/>
         <source>Number of tracks</source>
         <translation>Nombre de pistes</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="55"/>
+        <location filename="../xmpmetadatamodel.cpp" line="54"/>
         <source>Tracks per pattern</source>
         <translation>Pistes par pattern</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="56"/>
+        <location filename="../xmpmetadatamodel.cpp" line="55"/>
         <source>Number of instruments</source>
         <translation>Nombre d&apos;instruments</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="57"/>
+        <location filename="../xmpmetadatamodel.cpp" line="56"/>
         <source>Number of samples</source>
         <translation>Nombre de samples</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="58"/>
+        <location filename="../xmpmetadatamodel.cpp" line="57"/>
         <source>Initial speed</source>
         <translation>Vitesse initiale</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="59"/>
+        <location filename="../xmpmetadatamodel.cpp" line="58"/>
         <source>Initial BPM</source>
         <translation>BPM initial</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="60"/>
+        <location filename="../xmpmetadatamodel.cpp" line="59"/>
         <source>Module length in patterns</source>
         <translation>Longueur du module en pattern</translation>
     </message>
@@ -170,4 +97,87 @@
         <translation>Commentaire</translation>
     </message>
 </context>
+<context>
+    <name>XmpSettingsDialog</name>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="14"/>
+        <source>XMP Plugin Settings</source>
+        <translation>Paramètres du greffon XMP</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="34"/>
+        <source>Amplification factor:</source>
+        <translation>Facteur d&apos;amplification</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="51"/>
+        <source>Stereo mixing:</source>
+        <translation>Mixing Stéréo</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="68"/>
+        <source> Interpolation type:</source>
+        <translation>Type d&apos;interpolation</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="78"/>
+        <source>Lowpass filter effect</source>
+        <translation>Filtre avec effet lowpass</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="85"/>
+        <source>Use vblank timing</source>
+        <translation>Utiliser le timing vblank</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="92"/>
+        <source>Emulate Protracker 2.x FX9 bug</source>
+        <translation>Emuler le bug Protracker 2.x FX9</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="99"/>
+        <source>Sample rate:</source>
+        <translation>Taux du sample</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="109"/>
+        <source>Emulate sample loop bug</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="116"/>
+        <source>Use Paula mixer in Amiga modules</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.cpp" line="33"/>
+        <source>22050 Hz</source>
+        <translation>22 050 Hz</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.cpp" line="34"/>
+        <source>44100 Hz</source>
+        <translation>44 100 Hz</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.cpp" line="35"/>
+        <source>48000 Hz</source>
+        <translation>48 000 Hz</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.cpp" line="36"/>
+        <source>Nearest neighbor</source>
+        <translation>Voisin le plus proche</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.cpp" line="37"/>
+        <source>Linear</source>
+        <translation>Linéaire</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.cpp" line="38"/>
+        <source>Cubic spline</source>
+        <translation>Spline cubique</translation>
+    </message>
+</context>
 </TS>
