@@ -9,148 +9,75 @@
         <translation>XMP-plug-in</translation>
     </message>
     <message>
-        <location filename="../decoderxmpfactory.cpp" line="52"/>
+        <location filename="../decoderxmpfactory.cpp" line="54"/>
         <source>Module Files</source>
         <translation>Modulebestanden</translation>
     </message>
     <message>
-        <location filename="../decoderxmpfactory.cpp" line="108"/>
+        <location filename="../decoderxmpfactory.cpp" line="109"/>
         <source>About XMP Audio Plugin</source>
         <translation>Over de XMP-audioplug-in</translation>
     </message>
     <message>
-        <location filename="../decoderxmpfactory.cpp" line="109"/>
+        <location filename="../decoderxmpfactory.cpp" line="110"/>
         <source>Qmmp XMP Audio Plugin</source>
         <translation>XMP-audioplug-in voor Qmmp</translation>
     </message>
     <message>
-        <location filename="../decoderxmpfactory.cpp" line="110"/>
+        <location filename="../decoderxmpfactory.cpp" line="111"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
         <translation>Maker: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
     <message>
-        <location filename="../decoderxmpfactory.cpp" line="111"/>
+        <location filename="../decoderxmpfactory.cpp" line="112"/>
         <source>Compiled against libxmp-%1</source>
         <translation>Gebouwd met libxmp-%1</translation>
     </message>
 </context>
-<context>
-    <name>SettingsDialog</name>
-    <message>
-        <location filename="../settingsdialog.ui" line="14"/>
-        <source>XMP Plugin Settings</source>
-        <translation>Instellingen</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="34"/>
-        <source>Amplification factor:</source>
-        <translation>Versterkingsfactor:</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="51"/>
-        <source>Stereo mixing:</source>
-        <translation>Stereo mixen:</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="68"/>
-        <source> Interpolation type:</source>
-        <translation>Soort interpolatie:</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="78"/>
-        <source>Lowpass filter effect</source>
-        <translation>Lowpass-filtereffect</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="85"/>
-        <source>Use vblank timing</source>
-        <translation>vblank-timer gebruiken</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="92"/>
-        <source>Emulate Protracker 2.x FX9 bug</source>
-        <translation>Protracker 2.x FX9-bug nabootsen</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="99"/>
-        <source>Sample rate:</source>
-        <translation>Samplefrequentie:</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="33"/>
-        <source>22050 Hz</source>
-        <translation>22050 Hz</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="34"/>
-        <source>44100 Hz</source>
-        <translation>44100 Hz</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="35"/>
-        <source>48000 Hz</source>
-        <translation>48000 Hz</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="36"/>
-        <source>Nearest neighbor</source>
-        <translation>Nabije buur</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="37"/>
-        <source>Linear</source>
-        <translation>Lineair</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="38"/>
-        <source>Cubic spline</source>
-        <translation>Cubic spline</translation>
-    </message>
-</context>
 <context>
     <name>XmpMetaDataModel</name>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="52"/>
+        <location filename="../xmpmetadatamodel.cpp" line="51"/>
         <source>Volume scale</source>
         <translation>Volumeschaal</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="53"/>
+        <location filename="../xmpmetadatamodel.cpp" line="52"/>
         <source>Number of patterns</source>
         <translation>Aantal patronen</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="54"/>
+        <location filename="../xmpmetadatamodel.cpp" line="53"/>
         <source>Number of tracks</source>
         <translation>Aantal nummers</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="55"/>
+        <location filename="../xmpmetadatamodel.cpp" line="54"/>
         <source>Tracks per pattern</source>
         <translation>Aantal nummers per patroon</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="56"/>
+        <location filename="../xmpmetadatamodel.cpp" line="55"/>
         <source>Number of instruments</source>
         <translation>Aantal instrumenten</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="57"/>
+        <location filename="../xmpmetadatamodel.cpp" line="56"/>
         <source>Number of samples</source>
         <translation>Aantal samples</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="58"/>
+        <location filename="../xmpmetadatamodel.cpp" line="57"/>
         <source>Initial speed</source>
         <translation>Initële snelheid</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="59"/>
+        <location filename="../xmpmetadatamodel.cpp" line="58"/>
         <source>Initial BPM</source>
         <translation>Initiële BPM</translation>
     </message>
     <message>
-        <location filename="../xmpmetadatamodel.cpp" line="60"/>
+        <location filename="../xmpmetadatamodel.cpp" line="59"/>
         <source>Module length in patterns</source>
         <translation>Moduleduur, in patronen</translation>
     </message>
@@ -170,4 +97,87 @@
         <translation>Opmerking</translation>
     </message>
 </context>
+<context>
+    <name>XmpSettingsDialog</name>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="14"/>
+        <source>XMP Plugin Settings</source>
+        <translation>Instellingen</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="34"/>
+        <source>Amplification factor:</source>
+        <translation>Versterkingsfactor:</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="51"/>
+        <source>Stereo mixing:</source>
+        <translation>Stereo mixen:</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="68"/>
+        <source> Interpolation type:</source>
+        <translation>Soort interpolatie:</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="78"/>
+        <source>Lowpass filter effect</source>
+        <translation>Lowpass-filtereffect</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="85"/>
+        <source>Use vblank timing</source>
+        <translation>vblank-timer gebruiken</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="92"/>
+        <source>Emulate Protracker 2.x FX9 bug</source>
+        <translation>Protracker 2.x FX9-bug nabootsen</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="99"/>
+        <source>Sample rate:</source>
+        <translation>Samplesnelheid:</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="109"/>
+        <source>Emulate sample loop bug</source>
+        <translation>Sample-herhaalbug emuleren</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.ui" line="116"/>
+        <source>Use Paula mixer in Amiga modules</source>
+        <translation>Paula-mixer gebruiken in Amiga-modules</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.cpp" line="33"/>
+        <source>22050 Hz</source>
+        <translation>22050 Hz</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.cpp" line="34"/>
+        <source>44100 Hz</source>
+        <translation>44100 Hz</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.cpp" line="35"/>
+        <source>48000 Hz</source>
+        <translation>48000 Hz</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.cpp" line="36"/>
+        <source>Nearest neighbor</source>
+        <translation>Nabije buur</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.cpp" line="37"/>
+        <source>Linear</source>
+        <translation>Lineair</translation>
+    </message>
+    <message>
+        <location filename="../xmpsettingsdialog.cpp" line="38"/>
+        <source>Cubic spline</source>
+        <translation>Cubic spline</translation>
+    </message>
+</context>
 </TS>
