@@ -1,27 +1,27 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="sv">
+<TS version="2.1" language="sv_SE">
 <context>
     <name>OutputNullFactory</name>
     <message>
         <location filename="../outputnullfactory.cpp" line="30"/>
         <source>Null Plugin</source>
-        <translation>Null Plugin</translation>
-    </message>
-    <message>
-        <location filename="../outputnullfactory.cpp" line="54"/>
-        <source>About Null Output Plugin</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../outputnullfactory.cpp" line="55"/>
-        <source>Qmmp Null Output Plugin</source>
+        <source>About Null Output Plugin</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../outputnullfactory.cpp" line="56"/>
+        <source>Qmmp Null Output Plugin</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../outputnullfactory.cpp" line="57"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
-        <translation>Skriven av: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 </TS>
