@@ -1,6 +1,54 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="kk_KZ">
+<context>
+    <name>OssSettingsDialog</name>
+    <message>
+        <location filename="../osssettingsdialog.ui" line="14"/>
+        <source>OSS Plugin Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../osssettingsdialog.ui" line="33"/>
+        <source>Device Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../osssettingsdialog.ui" line="54"/>
+        <source>Audio device</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../osssettingsdialog.ui" line="70"/>
+        <source>Mixer device</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../osssettingsdialog.ui" line="102"/>
+        <source>Advanced Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../osssettingsdialog.ui" line="123"/>
+        <source>Soundcard</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../osssettingsdialog.ui" line="196"/>
+        <source>Buffer time (ms):</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../osssettingsdialog.ui" line="206"/>
+        <source>Period time (ms):</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../osssettingsdialog.ui" line="236"/>
+        <source>PCM over Master</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>OutputOSSFactory</name>
     <message>
@@ -9,72 +57,24 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../outputossfactory.cpp" line="56"/>
+        <location filename="../outputossfactory.cpp" line="55"/>
         <source>About OSS Output Plugin</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../outputossfactory.cpp" line="57"/>
+        <location filename="../outputossfactory.cpp" line="56"/>
         <source>Qmmp OSS Output Plugin</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../outputossfactory.cpp" line="58"/>
+        <location filename="../outputossfactory.cpp" line="57"/>
         <source>Written by: Yuriy Zhuravlev &lt;slalkerg@gmail.com&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../outputossfactory.cpp" line="59"/>
+        <location filename="../outputossfactory.cpp" line="58"/>
         <source>Based on code by: Brad Hughes &lt;bhughes@trolltech.com&gt;</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>SettingsDialog</name>
-    <message>
-        <location filename="../settingsdialog.ui" line="14"/>
-        <source>OSS Plugin Settings</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="33"/>
-        <source>Device Settings</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="45"/>
-        <source>Audio device</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="61"/>
-        <source>Mixer device</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="84"/>
-        <source>Advanced Settings</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="96"/>
-        <source>Soundcard</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="160"/>
-        <source>Buffer time (ms):</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="170"/>
-        <source>Period time (ms):</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="200"/>
-        <source>PCM over Master</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 </TS>
