@@ -1,6 +1,24 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="zh_TW">
+<context>
+    <name>Oss4SettingsDialog</name>
+    <message>
+        <location filename="../oss4settingsdialog.ui" line="14"/>
+        <source>OSS4 Plugin Settings</source>
+        <translation>OSS4 插件設定</translation>
+    </message>
+    <message>
+        <location filename="../oss4settingsdialog.ui" line="61"/>
+        <source>Device:</source>
+        <translation>設備：</translation>
+    </message>
+    <message>
+        <location filename="../oss4settingsdialog.cpp" line="69"/>
+        <source>Default (%1)</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>OutputOSS4Factory</name>
     <message>
@@ -9,37 +27,19 @@
         <translation>OSS4 外掛</translation>
     </message>
     <message>
-        <location filename="../outputoss4factory.cpp" line="56"/>
+        <location filename="../outputoss4factory.cpp" line="55"/>
         <source>About OSS4 Output Plugin</source>
         <translation>關於 OSS4 輸出插件</translation>
     </message>
     <message>
-        <location filename="../outputoss4factory.cpp" line="57"/>
+        <location filename="../outputoss4factory.cpp" line="56"/>
         <source>Qmmp OSS4 Output Plugin</source>
         <translation>Qmmp OSS4 輸出插件</translation>
     </message>
     <message>
-        <location filename="../outputoss4factory.cpp" line="58"/>
+        <location filename="../outputoss4factory.cpp" line="57"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
         <translation>撰寫：Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
 </context>
-<context>
-    <name>SettingsDialog</name>
-    <message>
-        <location filename="../settingsdialog.ui" line="14"/>
-        <source>OSS4 Plugin Settings</source>
-        <translation>OSS4 插件設定</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="61"/>
-        <source>Device:</source>
-        <translation>設備：</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="71"/>
-        <source>Default</source>
-        <translation>默認</translation>
-    </message>
-</context>
 </TS>
