@@ -6,22 +6,22 @@
     <message>
         <location filename="../outputqtmultimediafactory.cpp" line="32"/>
         <source>Qt Multimedia Plugin</source>
-        <translation>Qt 多媒體插件</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../outputqtmultimediafactory.cpp" line="56"/>
         <source>About Qt Multimedia Output Plugin</source>
-        <translation>關於 Qt 多媒體輸出插件</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../outputqtmultimediafactory.cpp" line="57"/>
         <source>Qmmp Qt Multimedia Output Plugin</source>
-        <translation>Qmmp Qt 多媒體輸出插件</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../outputqtmultimediafactory.cpp" line="58"/>
         <source>Written by: Ivan Ponomarev &lt;ivantrue@gmail.com&gt;</source>
-        <translation>撰寫：Ivan Ponomarev &lt;ivantrue@gmail.com&gt;</translation>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -29,7 +29,7 @@
     <message>
         <location filename="../qtmultimediasettingsdialog.ui" line="14"/>
         <source>Qt Multimedia Plugin Settings</source>
-        <translation>Qt 多媒體插件設定</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../qtmultimediasettingsdialog.ui" line="46"/>
@@ -37,7 +37,7 @@
         <translation>設備：</translation>
     </message>
     <message>
-        <location filename="../qtmultimediasettingsdialog.cpp" line="35"/>
+        <location filename="../qtmultimediasettingsdialog.cpp" line="36"/>
         <source>Default</source>
         <translation>默認</translation>
     </message>
