@@ -9,40 +9,50 @@
         <translation>Πρόσθετο WASAPI</translation>
     </message>
     <message>
-        <location filename="../outputwasapifactory.cpp" line="54"/>
+        <location filename="../outputwasapifactory.cpp" line="53"/>
         <source>About WASAPI Output Plugin</source>
         <translation>Περί του πρόσθετου εξόδου WASAPI</translation>
     </message>
     <message>
-        <location filename="../outputwasapifactory.cpp" line="55"/>
+        <location filename="../outputwasapifactory.cpp" line="54"/>
         <source>Qmmp WASAPI Output Plugin</source>
         <translation>Qmmp πρόσθετο εξόδου WASAPI</translation>
     </message>
     <message>
-        <location filename="../outputwasapifactory.cpp" line="56"/>
+        <location filename="../outputwasapifactory.cpp" line="55"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
         <translation>Γράφτηκε από τον: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
 </context>
 <context>
-    <name>SettingsDialog</name>
+    <name>WASAPISettingsDialog</name>
     <message>
-        <location filename="../settingsdialog.ui" line="14"/>
+        <location filename="../wasapisettingsdialog.ui" line="14"/>
         <source>WASAPI Plugin Settings</source>
         <translation>Ρυθμίσεις πρόσθετου WASAPI</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="61"/>
+        <location filename="../wasapisettingsdialog.ui" line="35"/>
         <source>Device:</source>
         <translation>Συσκευή:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="68"/>
+        <location filename="../wasapisettingsdialog.ui" line="55"/>
+        <source>Buffer size:</source>
+        <translation>Μέγεθος ενδιάμεσης μνήμης:</translation>
+    </message>
+    <message>
+        <location filename="../wasapisettingsdialog.ui" line="62"/>
+        <source>ms</source>
+        <translation>ms</translation>
+    </message>
+    <message>
+        <location filename="../wasapisettingsdialog.ui" line="78"/>
         <source>Exclusive mode</source>
         <translation>Αποκλειστική λειτουργία</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="58"/>
+        <location filename="../wasapisettingsdialog.cpp" line="65"/>
         <source>Default</source>
         <translation>Εξ ορισμού</translation>
     </message>
