@@ -9,37 +9,37 @@
         <translation>ММС прикључак</translation>
     </message>
     <message>
-        <location filename="../mmsinputfactory.cpp" line="52"/>
+        <location filename="../mmsinputfactory.cpp" line="51"/>
         <source>About MMS Transport Plugin</source>
         <translation>О прикључку ММС преноса</translation>
     </message>
     <message>
-        <location filename="../mmsinputfactory.cpp" line="53"/>
+        <location filename="../mmsinputfactory.cpp" line="52"/>
         <source>Qmmp MMS Transport Plugin</source>
         <translation>Кумп прикључак за ММС пренос</translation>
     </message>
     <message>
-        <location filename="../mmsinputfactory.cpp" line="54"/>
+        <location filename="../mmsinputfactory.cpp" line="53"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
         <translation>Аутор: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
 </context>
 <context>
-    <name>SettingsDialog</name>
+    <name>MmsSettingsDialog</name>
     <message>
-        <location filename="../settingsdialog.ui" line="14"/>
+        <location filename="../mmssettingsdialog.ui" line="14"/>
         <source>MMS Plugin Settings</source>
-        <translation>Поставке ММС прикључка</translation>
+        <translation type="unfinished">Поставке ММС прикључка</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="29"/>
+        <location filename="../mmssettingsdialog.ui" line="29"/>
         <source>Buffer size:</source>
-        <translation>Величина бафера:</translation>
+        <translation type="unfinished">Величина бафера:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="64"/>
+        <location filename="../mmssettingsdialog.ui" line="64"/>
         <source>KB</source>
-        <translation>KB</translation>
+        <translation type="unfinished">KB</translation>
     </message>
 </context>
 </TS>
