@@ -1,45 +1,45 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="uk">
+<TS version="2.1" language="uk_UA">
 <context>
     <name>MMSInputFactory</name>
     <message>
         <location filename="../mmsinputfactory.cpp" line="32"/>
         <source>MMS Plugin</source>
-        <translation>Модуль MMS</translation>
+        <translation>Втулок MMS</translation>
+    </message>
+    <message>
+        <location filename="../mmsinputfactory.cpp" line="51"/>
+        <source>About MMS Transport Plugin</source>
+        <translation>Про втулок MMS</translation>
     </message>
     <message>
         <location filename="../mmsinputfactory.cpp" line="52"/>
-        <source>About MMS Transport Plugin</source>
-        <translation>Про модуль MMS</translation>
+        <source>Qmmp MMS Transport Plugin</source>
+        <translation>Транспортний втулок MMS для Qmmp</translation>
     </message>
     <message>
         <location filename="../mmsinputfactory.cpp" line="53"/>
-        <source>Qmmp MMS Transport Plugin</source>
-        <translation>Транспортний модуль MMS для Qmmp</translation>
-    </message>
-    <message>
-        <location filename="../mmsinputfactory.cpp" line="54"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
         <translation>Розробник: Ілля Котов &lt;forkotov02@ya.ru&gt;</translation>
     </message>
 </context>
 <context>
-    <name>SettingsDialog</name>
+    <name>MmsSettingsDialog</name>
     <message>
-        <location filename="../settingsdialog.ui" line="14"/>
+        <location filename="../mmssettingsdialog.ui" line="14"/>
         <source>MMS Plugin Settings</source>
-        <translation>Налаштування модуля MMS</translation>
+        <translation>Налаштування втулка MMS</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="29"/>
+        <location filename="../mmssettingsdialog.ui" line="29"/>
         <source>Buffer size:</source>
-        <translation>Розмір буфера:</translation>
+        <translation>Розмір буферу:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="64"/>
+        <location filename="../mmssettingsdialog.ui" line="64"/>
         <source>KB</source>
-        <translation>Кб</translation>
+        <translation>КБ</translation>
     </message>
 </context>
 </TS>
