@@ -9,35 +9,35 @@
         <translation>MMS 外掛</translation>
     </message>
     <message>
-        <location filename="../mmsinputfactory.cpp" line="52"/>
+        <location filename="../mmsinputfactory.cpp" line="51"/>
         <source>About MMS Transport Plugin</source>
         <translation>關於 MMS 傳輸插件</translation>
     </message>
     <message>
-        <location filename="../mmsinputfactory.cpp" line="53"/>
+        <location filename="../mmsinputfactory.cpp" line="52"/>
         <source>Qmmp MMS Transport Plugin</source>
         <translation>Qmmp MMS 傳輸插件</translation>
     </message>
     <message>
-        <location filename="../mmsinputfactory.cpp" line="54"/>
+        <location filename="../mmsinputfactory.cpp" line="53"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
         <translation>撰寫：Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
 </context>
 <context>
-    <name>SettingsDialog</name>
+    <name>MmsSettingsDialog</name>
     <message>
-        <location filename="../settingsdialog.ui" line="14"/>
+        <location filename="../mmssettingsdialog.ui" line="14"/>
         <source>MMS Plugin Settings</source>
         <translation>MMS 插件設定</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="29"/>
+        <location filename="../mmssettingsdialog.ui" line="29"/>
         <source>Buffer size:</source>
         <translation>緩沖大小：</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="64"/>
+        <location filename="../mmssettingsdialog.ui" line="64"/>
         <source>KB</source>
         <translation>KB</translation>
     </message>
