@@ -126,7 +126,7 @@
     <message>
         <location filename="../skinnedactionmanager.cpp" line="51"/>
         <source>&amp;Transit between playlists</source>
-        <translation>在播放列表间切换(&amp;T)</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../skinnedactionmanager.cpp" line="52"/>
@@ -421,12 +421,12 @@
     <message>
         <location filename="../skinnedactionmanager.cpp" line="89"/>
         <source>Show &amp;Tab Bar</source>
-        <translation>显示标签页栏(&amp;T)</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../skinnedactionmanager.cpp" line="89"/>
         <source>Alt+T</source>
-        <translation>Alt+T</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../skinnedactionmanager.cpp" line="91"/>
@@ -462,88 +462,87 @@
 <context>
     <name>SkinnedDisplay</name>
     <message>
-        <location filename="../skinneddisplay.cpp" line="60"/>
+        <location filename="../skinneddisplay.cpp" line="59"/>
         <source>Previous</source>
         <translation>上一个</translation>
     </message>
     <message>
-        <location filename="../skinneddisplay.cpp" line="64"/>
+        <location filename="../skinneddisplay.cpp" line="63"/>
         <source>Play</source>
         <translation>播放</translation>
     </message>
     <message>
-        <location filename="../skinneddisplay.cpp" line="67"/>
+        <location filename="../skinneddisplay.cpp" line="66"/>
         <source>Pause</source>
         <translation>暂停</translation>
     </message>
     <message>
-        <location filename="../skinneddisplay.cpp" line="70"/>
+        <location filename="../skinneddisplay.cpp" line="69"/>
         <source>Stop</source>
         <translation>停止</translation>
     </message>
     <message>
-        <location filename="../skinneddisplay.cpp" line="73"/>
+        <location filename="../skinneddisplay.cpp" line="72"/>
         <source>Next</source>
         <translation>下一首</translation>
     </message>
     <message>
-        <location filename="../skinneddisplay.cpp" line="76"/>
+        <location filename="../skinneddisplay.cpp" line="75"/>
         <source>Play files</source>
         <translation>播放文件</translation>
     </message>
     <message>
-        <location filename="../skinneddisplay.cpp" line="81"/>
+        <location filename="../skinneddisplay.cpp" line="80"/>
         <source>Equalizer</source>
         <translation>均衡器</translation>
     </message>
     <message>
-        <location filename="../skinneddisplay.cpp" line="83"/>
+        <location filename="../skinneddisplay.cpp" line="82"/>
         <source>Playlist</source>
         <translation>播放列表</translation>
     </message>
     <message>
-        <location filename="../skinneddisplay.cpp" line="86"/>
+        <location filename="../skinneddisplay.cpp" line="85"/>
         <source>Repeat playlist</source>
         <translation>重复播放列表</translation>
     </message>
     <message>
-        <location filename="../skinneddisplay.cpp" line="88"/>
+        <location filename="../skinneddisplay.cpp" line="87"/>
         <source>Shuffle</source>
         <translation>乱序</translation>
     </message>
     <message>
-        <location filename="../skinneddisplay.cpp" line="98"/>
+        <location filename="../skinneddisplay.cpp" line="97"/>
         <source>Volume</source>
         <translation>音量</translation>
     </message>
     <message>
-        <location filename="../skinneddisplay.cpp" line="108"/>
+        <location filename="../skinneddisplay.cpp" line="103"/>
         <source>Balance</source>
         <translation>平衡</translation>
     </message>
     <message>
-        <location filename="../skinneddisplay.cpp" line="295"/>
-        <location filename="../skinneddisplay.cpp" line="321"/>
+        <location filename="../skinneddisplay.cpp" line="290"/>
         <source>Volume: %1%</source>
         <translation>音量：%1%</translation>
     </message>
     <message>
-        <location filename="../skinneddisplay.cpp" line="299"/>
+        <location filename="../skinneddisplay.cpp" line="294"/>
         <source>Balance: %1% right</source>
         <translation>平衡：%1% 右</translation>
     </message>
     <message>
-        <location filename="../skinneddisplay.cpp" line="301"/>
+        <location filename="../skinneddisplay.cpp" line="296"/>
         <source>Balance: %1% left</source>
         <translation>平衡：%1% 左</translation>
     </message>
     <message>
-        <location filename="../skinneddisplay.cpp" line="303"/>
+        <location filename="../skinneddisplay.cpp" line="298"/>
         <source>Balance: center</source>
         <translation>平衡：居中</translation>
     </message>
     <message>
-        <location filename="../skinneddisplay.cpp" line="309"/>
+        <location filename="../skinneddisplay.cpp" line="304"/>
         <source>Seek to: %1</source>
         <translation>搜寻到：%1</translation>
     </message>
@@ -602,7 +601,7 @@
         <translation>预设 #</translation>
     </message>
     <message>
-        <location filename="../skinnedeqwidget.cpp" line="392"/>
+        <location filename="../skinnedeqwidget.cpp" line="394"/>
         <source>Import Preset</source>
         <translation>导入预设</translation>
     </message>
@@ -615,49 +614,49 @@
         <translation>皮肤化用户界面</translation>
     </message>
     <message>
-        <location filename="../skinnedfactory.cpp" line="62"/>
+        <location filename="../skinnedfactory.cpp" line="61"/>
         <source>About Qmmp Skinned User Interface</source>
         <translation>关于Qmmp皮肤化用户界面</translation>
     </message>
     <message>
-        <location filename="../skinnedfactory.cpp" line="63"/>
+        <location filename="../skinnedfactory.cpp" line="62"/>
         <source>Qmmp Skinned User Interface</source>
         <translation>Qmmp皮肤化用户界面</translation>
     </message>
     <message>
-        <location filename="../skinnedfactory.cpp" line="64"/>
+        <location filename="../skinnedfactory.cpp" line="63"/>
         <source>Simple user interface with Winamp-2.x/XMMS skins support</source>
         <translation>支持Winamp-2.x/XMMS皮肤的简单用户界面</translation>
     </message>
     <message>
-        <location filename="../skinnedfactory.cpp" line="65"/>
+        <location filename="../skinnedfactory.cpp" line="64"/>
         <source>Written by:</source>
         <translation>作者：</translation>
     </message>
     <message>
-        <location filename="../skinnedfactory.cpp" line="66"/>
+        <location filename="../skinnedfactory.cpp" line="65"/>
         <source>Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;</source>
         <translation>Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;</translation>
     </message>
     <message>
-        <location filename="../skinnedfactory.cpp" line="67"/>
+        <location filename="../skinnedfactory.cpp" line="66"/>
         <source>Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
-        <translation>Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../skinnedfactory.cpp" line="68"/>
+        <location filename="../skinnedfactory.cpp" line="67"/>
         <source>Artwork:</source>
         <translation>艺术制作</translation>
     </message>
     <message>
-        <location filename="../skinnedfactory.cpp" line="69"/>
+        <location filename="../skinnedfactory.cpp" line="68"/>
         <source>Andrey Adreev &lt;andreev00@gmail.com&gt;</source>
         <translation>Andrey Adreev &lt;andreev00@gmail.com&gt;</translation>
     </message>
     <message>
-        <location filename="../skinnedfactory.cpp" line="70"/>
+        <location filename="../skinnedfactory.cpp" line="69"/>
         <source>sixsixfive &lt;http://sixsixfive.deviantart.com/&gt;</source>
-        <translation>sixsixfive &lt;http://sixsixfive.deviantart.com/&gt;</translation>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1087,12 +1086,12 @@
     <message>
         <location filename="../forms/skinnedsettings.ui" line="308"/>
         <source>Show splitters</source>
-        <translation>显示分隔符</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../forms/skinnedsettings.ui" line="315"/>
         <source>Alternate splitter color</source>
-        <translation>备用分隔符颜色</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../forms/skinnedsettings.ui" line="415"/>
@@ -1107,7 +1106,7 @@
     <message>
         <location filename="../forms/skinnedsettings.ui" line="427"/>
         <source>Use skin colors</source>
-        <translation>使用皮肤颜色</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../forms/skinnedsettings.ui" line="545"/>
@@ -1127,7 +1126,7 @@
     <message>
         <location filename="../forms/skinnedsettings.ui" line="763"/>
         <source>Splitter:</source>
-        <translation>分隔符：</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../forms/skinnedsettings.ui" line="577"/>
@@ -1142,7 +1141,7 @@
     <message>
         <location filename="../forms/skinnedsettings.ui" line="813"/>
         <source>Current track background:</source>
-        <translation>当前曲目背景：</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../forms/skinnedsettings.ui" line="871"/>
@@ -1172,7 +1171,7 @@
     <message>
         <location filename="../forms/skinnedsettings.ui" line="691"/>
         <source>Load skin colors</source>
-        <translation>载入皮肤颜色</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../forms/skinnedsettings.ui" line="904"/>
@@ -1187,12 +1186,12 @@
     <message>
         <location filename="../forms/skinnedsettings.ui" line="994"/>
         <source>Groups:</source>
-        <translation>分组：</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../forms/skinnedsettings.ui" line="1021"/>
         <source>Extra group row:</source>
-        <translation>额外的分组行：</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../forms/skinnedsettings.ui" line="1048"/>
@@ -1329,17 +1328,17 @@
     <message>
         <location filename="../skinnedsettings.cpp" line="165"/>
         <source>Default skin</source>
-        <translation>默认皮肤：</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../skinnedsettings.cpp" line="174"/>
         <source>Unarchived skin %1</source>
-        <translation>未存档皮肤 %1</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../skinnedsettings.cpp" line="174"/>
         <source>Archived skin %1</source>
-        <translation>存档的皮肤 %1</translation>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
