@@ -9,82 +9,84 @@
         <translation>Qmmp 可视化分析器</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="314"/>
+        <location filename="../analyzer.cpp" line="320"/>
         <source>Peaks</source>
         <translation>峰</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="317"/>
+        <location filename="../analyzer.cpp" line="323"/>
         <source>Refresh Rate</source>
         <translation>刷新率</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="320"/>
+        <location filename="../analyzer.cpp" line="326"/>
         <source>50 fps</source>
         <translation>50 fps</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="321"/>
+        <location filename="../analyzer.cpp" line="327"/>
         <source>25 fps</source>
         <translation>25 帧每秒</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="322"/>
+        <location filename="../analyzer.cpp" line="328"/>
         <source>10 fps</source>
         <translation>10 帧每秒</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="323"/>
+        <location filename="../analyzer.cpp" line="329"/>
         <source>5 fps</source>
         <translation>5 帧每秒</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="330"/>
+        <location filename="../analyzer.cpp" line="336"/>
         <source>Analyzer Falloff</source>
         <translation>分析器坠落</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="333"/>
-        <location filename="../analyzer.cpp" line="347"/>
+        <location filename="../analyzer.cpp" line="339"/>
+        <location filename="../analyzer.cpp" line="353"/>
         <source>Slowest</source>
         <translation>最慢</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="334"/>
-        <location filename="../analyzer.cpp" line="348"/>
+        <location filename="../analyzer.cpp" line="340"/>
+        <location filename="../analyzer.cpp" line="354"/>
         <source>Slow</source>
         <translation>慢</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="335"/>
-        <location filename="../analyzer.cpp" line="349"/>
+        <location filename="../analyzer.cpp" line="341"/>
+        <location filename="../analyzer.cpp" line="355"/>
         <source>Medium</source>
         <translation>中等</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="336"/>
-        <location filename="../analyzer.cpp" line="350"/>
+        <location filename="../analyzer.cpp" line="342"/>
+        <location filename="../analyzer.cpp" line="356"/>
         <source>Fast</source>
         <translation>快</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="337"/>
-        <location filename="../analyzer.cpp" line="351"/>
+        <location filename="../analyzer.cpp" line="343"/>
+        <location filename="../analyzer.cpp" line="357"/>
         <source>Fastest</source>
         <translation>最快</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="344"/>
+        <location filename="../analyzer.cpp" line="350"/>
         <source>Peaks Falloff</source>
         <translation>顶峰坠落</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="358"/>
+        <location filename="../analyzer.cpp" line="365"/>
+        <location filename="../analyzer.cpp" line="367"/>
         <source>&amp;Full Screen</source>
         <translation>全屏(&amp;F)</translation>
     </message>
     <message>
-        <location filename="../analyzer.cpp" line="358"/>
+        <location filename="../analyzer.cpp" line="365"/>
+        <location filename="../analyzer.cpp" line="367"/>
         <source>F</source>
         <translation>F</translation>
     </message>
@@ -165,7 +167,7 @@
     <message>
         <location filename="../visualanalyzerfactory.cpp" line="51"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
-        <translation>作者：Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 </TS>
