@@ -6,12 +6,12 @@
     <message>
         <location filename="../projectm4widget.cpp" line="163"/>
         <source>&amp;Show Menu</source>
-        <translation>&amp; 顯示功能表</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../projectm4widget.cpp" line="163"/>
         <source>M</source>
-        <translation>M</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../projectm4widget.cpp" line="165"/>
@@ -26,7 +26,7 @@
     <message>
         <location filename="../projectm4widget.cpp" line="166"/>
         <source>&amp;Previous Preset</source>
-        <translation>上一邊框形式</translation>
+        <translation>上一邊框形式(&amp;P)</translation>
     </message>
     <message>
         <location filename="../projectm4widget.cpp" line="166"/>
@@ -36,7 +36,7 @@
     <message>
         <location filename="../projectm4widget.cpp" line="167"/>
         <source>&amp;Shuffle</source>
-        <translation>亂序</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../projectm4widget.cpp" line="167"/>
@@ -75,92 +75,110 @@
 <context>
     <name>ProjectMWidget</name>
     <message>
-        <location filename="../projectmwidget.cpp" line="143"/>
+        <location filename="../projectmwidget.cpp" line="144"/>
+        <location filename="../projectmwidget.cpp" line="156"/>
         <source>&amp;Help</source>
         <translation>幫助(&amp;H)</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="143"/>
+        <location filename="../projectmwidget.cpp" line="144"/>
+        <location filename="../projectmwidget.cpp" line="156"/>
         <source>F1</source>
         <translation>F1</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="144"/>
+        <location filename="../projectmwidget.cpp" line="145"/>
+        <location filename="../projectmwidget.cpp" line="157"/>
         <source>&amp;Show Song Title</source>
         <translation>顯示曲目標題(&amp;S)</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="144"/>
+        <location filename="../projectmwidget.cpp" line="145"/>
+        <location filename="../projectmwidget.cpp" line="157"/>
         <source>F2</source>
         <translation>F2</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="145"/>
+        <location filename="../projectmwidget.cpp" line="146"/>
+        <location filename="../projectmwidget.cpp" line="158"/>
         <source>&amp;Show Preset Name</source>
         <translation>顯示邊框形式名稱(&amp;S)</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="145"/>
+        <location filename="../projectmwidget.cpp" line="146"/>
+        <location filename="../projectmwidget.cpp" line="158"/>
         <source>F3</source>
         <translation>F3</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="146"/>
+        <location filename="../projectmwidget.cpp" line="147"/>
+        <location filename="../projectmwidget.cpp" line="159"/>
         <source>&amp;Show Menu</source>
-        <translation>&amp; 顯示功能表</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="146"/>
+        <location filename="../projectmwidget.cpp" line="147"/>
+        <location filename="../projectmwidget.cpp" line="159"/>
         <source>M</source>
-        <translation>M</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="148"/>
+        <location filename="../projectmwidget.cpp" line="149"/>
+        <location filename="../projectmwidget.cpp" line="161"/>
         <source>&amp;Next Preset</source>
         <translation>下一邊框形式(&amp;N)</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="148"/>
+        <location filename="../projectmwidget.cpp" line="149"/>
+        <location filename="../projectmwidget.cpp" line="161"/>
         <source>N</source>
         <translation>N</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="149"/>
+        <location filename="../projectmwidget.cpp" line="150"/>
+        <location filename="../projectmwidget.cpp" line="162"/>
         <source>&amp;Previous Preset</source>
-        <translation>上一邊框形式</translation>
+        <translation>上一邊框形式(&amp;P)</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="149"/>
+        <location filename="../projectmwidget.cpp" line="150"/>
+        <location filename="../projectmwidget.cpp" line="162"/>
         <source>P</source>
         <translation>P</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="150"/>
+        <location filename="../projectmwidget.cpp" line="151"/>
+        <location filename="../projectmwidget.cpp" line="163"/>
         <source>&amp;Random Preset</source>
         <translation>隨意邊框形式(&amp;R)</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="150"/>
+        <location filename="../projectmwidget.cpp" line="151"/>
+        <location filename="../projectmwidget.cpp" line="163"/>
         <source>R</source>
         <translation>R</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="151"/>
+        <location filename="../projectmwidget.cpp" line="152"/>
+        <location filename="../projectmwidget.cpp" line="164"/>
         <source>&amp;Lock Preset</source>
         <translation>鎖定邊框形式(&amp;L)</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="151"/>
+        <location filename="../projectmwidget.cpp" line="152"/>
+        <location filename="../projectmwidget.cpp" line="164"/>
         <source>L</source>
         <translation>L</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="153"/>
+        <location filename="../projectmwidget.cpp" line="154"/>
+        <location filename="../projectmwidget.cpp" line="166"/>
         <source>&amp;Fullscreen</source>
         <translation>全屏(&amp;F)</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="153"/>
+        <location filename="../projectmwidget.cpp" line="154"/>
+        <location filename="../projectmwidget.cpp" line="166"/>
         <source>F</source>
         <translation>F</translation>
     </message>
@@ -185,12 +203,12 @@
     <message>
         <location filename="../visualprojectmfactory.cpp" line="52"/>
         <source>This plugin adds projectM visualization</source>
-        <translation>此插件添加 ProjectM可視化</translation>
+        <translation>此插件添加 ProjectM 可視化</translation>
     </message>
     <message>
         <location filename="../visualprojectmfactory.cpp" line="53"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
-        <translation>作者：Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
+        <translation>撰寫：Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
     <message>
         <location filename="../visualprojectmfactory.cpp" line="54"/>
