@@ -125,7 +125,7 @@ void Decoder::loadPlugins()
         return;
 
     m_cache = new QList<QmmpPluginCache*>;
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     for(const QString &filePath : Qmmp::findPlugins(u"Input"_s))
     {
         QmmpPluginCache *item = new QmmpPluginCache(filePath, &settings);
@@ -139,18 +139,6 @@ void Decoder::loadPlugins()
     m_disabledNames = settings.value(u"Decoder/disabled_plugins"_s).toStringList();
     std::stable_sort(m_cache->begin(), m_cache->end(), _pluginCacheLessComparator);
     QmmpPluginCache::cleanup(&settings);
-
-    qAddPostRoutine(Decoder::updateCache);
-}
-
-void Decoder::updateCache()
-{
-    if(m_cache)
-    {
-        QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-        for(QmmpPluginCache *item : std::as_const(*m_cache))
-            item->update(&settings);
-    }
 }
 
 QString Decoder::file(const DecoderFactory *factory)
@@ -303,7 +291,7 @@ void Decoder::setEnabled(DecoderFactory *factory, bool enable)
         m_disabledNames.append(factory->properties().shortName);
 
     m_disabledNames.removeDuplicates();
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.setValue(u"Decoder/disabled_plugins"_s, m_disabledNames);
 }
 
