@@ -10,6 +10,7 @@
 #include <QStringList>
 #include <QList>
 #include <QMap>
+#include <QVariant>
 #include <QIODevice>
 #include "qmmp.h"
 #include "audioparameters.h"
@@ -76,11 +77,11 @@ public:
     /*!
      * Returns detected audio parameters.
      */
-    AudioParameters audioParameters() const;
+    const AudioParameters &audioParameters() const;
     /*!
      * Returns ReplayGain information.
      */
-    QMap<Qmmp::ReplayGainKey, double> replayGainInfo() const;
+    const QMap<Qmmp::ReplayGainKey, double> &replayGainInfo() const;
     /*!
      * Sets ReplayGain information. Use this function before playback.
      * @param rg ReplayGain information
@@ -119,7 +120,7 @@ public:
     /*!
      * Returns track properties
      */
-    const QMap<Qmmp::TrackProperty, QString> &properties() const;
+    QMap<Qmmp::TrackProperty, QString> properties() const;
     /*!
      * Returns DecoderFactory pointer which supports file \b path or nullptr if file \b path is unsupported
      * @param path Full local file path.
@@ -152,6 +153,14 @@ public:
      * Returns a list of enabled decoder factories.
      */
     static QList<DecoderFactory*> enabledFactories();
+    /*!
+     * Returns a list of file name filters, i.e. "*.mp3 *.mpg".
+     */
+    static QStringList nameFilters();
+    /*!
+     * Returns a list of the supported mime types.
+     */
+    static QStringList contentTypes();
     /*!
      * Returns plugin file path.
      * @param factory Decoder plugin factory.
@@ -202,7 +211,7 @@ private:
     AudioParameters m_parameters;
     QMap<Qmmp::TrackProperty, QString> m_properties;
     QIODevice *m_input;
-    bool m_hasMetaData;
+    bool m_hasMetaData = false;
     QMap<Qmmp::MetaData, QString> m_metaData;
     QMap <Qmmp::ReplayGainKey, double> m_rg; //replay gain information
 };
