@@ -2,7 +2,7 @@
  *  Based on madplay project                                               *
  *                                                                         *
  * Copyright (C) 2000-2004 Robert Leslie <rob@mars.org>                    *
- * Copyright (C) 2016-2020 Ilya Kotov forkotov02@ya.ru                     *
+ * Copyright (C) 2016-2024 Ilya Kotov forkotov02@ya.ru                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -60,7 +60,7 @@ void Dithering::setFormats(Qmmp::AudioFormat in, Qmmp::AudioFormat out)
             ;
         }
     }
-    (m_required && m_enabled) ? qDebug("Dithering: enabled") : qDebug("Dithering: disabled");
+     qCDebug(core) << ((m_required && m_enabled) ? "enabled" : "disabled");
 }
 
 void Dithering::applyEffect(Buffer *b)
@@ -75,7 +75,7 @@ void Dithering::applyEffect(Buffer *b)
 void Dithering::setEnabled(bool enabled)
 {
     m_enabled = enabled;
-    (m_required && m_enabled) ? qDebug("Dithering: enabled") : qDebug("Dithering: disabled");
+    qCDebug(core) << ((m_required && m_enabled) ? "enabled" : "disabled");
 }
 
 void Dithering::clearHistory()
