@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2013-2020 by Ilya Kotov                                 *
+ *   Copyright (C) 2013-2025 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -43,12 +43,12 @@ public:
     /*!
      * Constructs a new PlayListTrack that is a copy of the given track \b other
      */
-    PlayListTrack(const PlayListTrack &other);
+    explicit PlayListTrack(const PlayListTrack &other);
     /*!
      * Constructs plalist item with given metadata.
      * @param info Media file information.
      */
-    PlayListTrack(TrackInfo *info);
+    PlayListTrack(const TrackInfo *info);
     /*!
      * Object destructor.
      */
@@ -61,15 +61,15 @@ public:
      * Returns formatted title of the item.
      * @param column Number of column.
      */
-    QString formattedTitle(int column) override;
+    QString formattedTitle(int column) const override;
     /*!
      * Returns the list of the formatted titles for all columns.
      */
-    QStringList formattedTitles() override;
+    QStringList formattedTitles() const override;
     /*!
      *  Returns formatted length of the item.
      */
-    QString formattedLength() override;
+    QString formattedDuration() const override;
     /*!
      *  Updates current metadata.
      *  @param info Track information.
@@ -87,15 +87,19 @@ public:
      * Returns \b false.
      */
     bool isGroup() const override;
-    /*!
-     * Sets the index of the track.
-     */
-    void setTrackIndex(int track_index) override;
     /*!
      * Returns the index of the track.
      * Default implementation returns -1.
      */
     int trackIndex() const override;
+    /*!
+     * Returns index of the queued track. Unqueued track returns \b -1.
+     */
+    int queuedIndex() const;
+    /*!
+     * Returns \b true if track is queued. Otherwise returns \b false.
+     */
+    bool isQueued() const;
     /*!
      * Prepares for usage.
      * Increases reference counter.
@@ -121,18 +125,23 @@ public:
     bool isUsed() const;
 
 private:
-    void formatTitle(int column);
-    void formatGroup();
-    QStringList m_formattedTitles;
-    QString m_formattedLength;
-    QString m_group;
-    QStringList m_titleFormats;
+    void formatTitle(int column) const;
+    void formatGroup() const;
+    mutable QStringList m_formattedTitles;
+    mutable QString m_formattedLength;
+    mutable QString m_group;
+    mutable QStringList m_titleFormats;
     QString m_groupFormat;
     QmmpUiSettings *m_settings;
-    int m_refCount;
-    int m_track_index;
-    bool m_sheduledForDeletion;
+    int m_refCount = 0;
+    bool m_sheduledForDeletion = false;
     MetaDataHelper *m_helper;
+    friend class PlayListContainer;
+    friend class NormalContainer;
+    friend class GroupedContainer;
+    int m_queued_index = -1;
+    int m_track_index = -1;
+
 };
 
 #endif
